drop _all
log using datav1,replace
*
* This STATA extracts macroeconomic data from the Deluge data set.
* This is then combined with the DOT data set.
*
set more 1
set maxobs 4000
*
* First clean up the macro data
*
use \res\deluge\data\datav8
drop finbal strubal primbal netlia ifs1dd ifs1ld ifs31n ifs35 ifs61 ifs62 ifs65 ifs77ad ifs78d ifs80 ip isk un wage wr gifsrf gifs1ld gifs34 gifs35 gifs60b aifsrf aifs1ld aifs34 aifs35 aifs60b gifs32 gifs61 gifs62 gifs64 gifs66i gifs70d gifs71d gcacc gbudg gifs99 gifs99ab get gunr gwr aifs32 aifs61 aifs62 aifs64 aifs66i aifs70d aifs71d acacc abudg aifs99 aifs99ab aet aunr awr gfinbal gstrubal gprimbal gnetlia
g date10=date*10
compress
sort ifscode date10
save crap,replace
drop _all
*
* Now work on the DOT data
*
use \res\oca\data\exports
drop if year<1959
replace ifscode=124 if ifscode==126
replace ifscode=138 if ifscode==137
g date10=(year*10.)+1
drop year
compress
sort ifscode date10
save crapx,replace
drop _all

use \res\oca\data\imports
drop if year<1959
replace ifscode=124 if ifscode==126
replace ifscode=138 if ifscode==137
g date10=(year*10.)+1
drop year
compress
sort ifscode date10
save crapm,replace
drop _all

use \res\oca\data\newtrade
replace ifscode=124 if ifscode==126
replace ifscode=138 if ifscode==137
g date10=(date*10.)+1
drop date
compress
sort ifscode date10
save crapt,replace
drop _all

use crapx
merge ifscode date10 using crapm
tab _merge
drop _merge
append using crapt
compress
sort ifscode date10
save crapo,replace
*
* Merge it with the macro stuff and save
*
merge ifscode date10 using crap
tab _merge
drop _merge
sort ifscode date
*
* Create Empty Variables for Exchange Rate Regimes
*
g byte fixed=.
g byte fltng=.

label var fixed "Fixed Rate Dummy"
label var fltng "Floating Rate Dummy"
*
* Start each variable off as a fixer except for Canada
*
replace fixed=1 if date<1959.15
replace fixed=0 if date<1959.15&ifscode==156
replace fltng=1 if date<1959.15&ifscode==156
*
* Add the periods when the country fixed its currency mid-sample
*
replace fixed=1 if fix==1&(floatn~=1)
*
* Iterate up, period by period, for countries staying fixed
*
replace fixed=1 if (fixed[_n-1]==1&ifscode==ifscode[_n-1])&(floatn~=1)
*
* Add the periods when the country floated its currency mid-sample
*
replace fltng=1 if floatn==1&(fix~=1)
*
* Now iterate up, period by period, for countries staying floating
*
replace fltng=1 if (fltng[_n-1]==1&ifscode==ifscode[_n-1])&(fix~=1)
*
* Fill in the missing exchange rate regime observations
*
count if fixed==1&fltng==1
replace fixed=0 if fltng==1
replace fltng=0 if fixed==1
tab fixed
tab fltng
tab fixed fltng
count if fixed==1&fltng==1
count if fixed==0&fltng==0
count if fixed==.&fltng==.
list ifscode country date fix floatn dwidth devaln revaln other if fixed==.&fltng==.
*
* Create EMS data.
*
g byte ems=0

label var ems "EMS Dummy"

replace ems=1 if ifscode==112&(date>1990.35&ifscode<1992.35)
replace ems=1 if ifscode==136&(date>1979.15&ifscode<1992.35)
replace ems=1 if ifscode==182&date>1992.15
replace ems=1 if ifscode==184&date>1990.15
replace ems=1 if ifscode==122&date>1994.05
replace ems=1 if ifscode==124&date>1979.15
replace ems=1 if ifscode==134&date>1979.15
replace ems=1 if ifscode==128&date>1979.15
replace ems=1 if ifscode==132&date>1979.15
replace ems=1 if ifscode==138&date>1979.15
replace ems=1 if ifscode==178&date>1979.15
*
* Create EEC/EC/EU data.
*
g byte eu=0

label var eu "EEC/EC/EU Dummy"

replace eu=1 if ifscode==124
replace eu=1 if ifscode==132
replace eu=1 if ifscode==134
replace eu=1 if ifscode==136
replace eu=1 if ifscode==138
replace eu=1 if ifscode==112&date>1973.05
replace eu=1 if ifscode==128&date>1973.05
replace eu=1 if ifscode==178&date>1973.05
replace eu=1 if ifscode==174&date>1981.05
replace eu=1 if ifscode==182&date>1986.05
replace eu=1 if ifscode==184&date>1986.05
*
* Create NAFTA data.
*
g byte nafta=0
label var nafta "NAFTA Dummy"
replace nafta=1 if ifscode==111&date>1988.05
replace nafta=1 if ifscode==156&date>1988.05
*
* Create ANZCERTA data.
*
g byte anz=0
label var anz "ANZCERTA Dummy"
replace anz=1 if ifscode==193&date>1965.05
replace anz=1 if ifscode==196&date>1965.05
*
* Create GATT data.
*
g byte gatt=1
label var gatt "GATT Dummy"
replace gatt=0 if ifscode==178&date<1968.05
replace gatt=0 if ifscode==182&date<1962.15
replace gatt=0 if ifscode==184&date<1963.35
replace gatt=0 if ifscode==146&date<1966.35

compress
sort ifscode date
drop if date10>19934.5
save \res\oca\data\datav1,replace
*
* Close Down
*
!del crap*.*
drop _all
log close
exit,clear
