drop _all
log using datav2,replace
*
* This STATA detrends four variables (output, industrial production, total
* employment, and the unemployment rate) in four different ways: 1) (fourth-
* order) differencing; 2) regression on quarterly dummies, time and its
* square; 3) HP-filtering; and 4) HP-filtering on a de-seasonalized residual.
*
set more 1
set maxobs 4000
set matsize 210
*
* Read in the data
*
use \res\oca\data\datav1b
rename ifs66i ifs66
*
* Detrend via fourth-differencing
*
g dlifs99=100.*(log(ifs99)-log(ifs99[_n-4])) if ifscode==ifscode[_n-4]
replace dlifs99=. if  ifscode~=ifscode[_n-4]
label var dlifs99 "Fourth-Difference, Log of ifs99"

g dlifs66=100.*(log(ifs66)-log(ifs66[_n-4])) if ifscode==ifscode[_n-4]
replace dlifs66=. if  ifscode~=ifscode[_n-4]
label var dlifs66 "Fourth-Difference, Log of ifs66"

g dlet=100.*(log(et)-log(et[_n-4])) if ifscode==ifscode[_n-4]
replace dlet=. if  ifscode~=ifscode[_n-4]
label var dlet "Fourth-Difference, Log of et"

g dunr=100.*(unr-unr[_n-4]) if ifscode==ifscode[_n-4]
replace dunr=. if  ifscode~=ifscode[_n-4]
label var dunr "Fourth-Difference, Log of unr"
*
* Prepare for regression and HP detrending
*
g time=1 in 1/1
replace time=time[_n-1]+1 in 2/140
replace time=time[_n-140] in 141/l
g timesq=time^2.
g q1=1 in 1/1
replace q1=0 in 2/4
g q2=1 in 2/2
replace q2=0 in 3/4
replace q2=0 in 1/1
g q3=1 in 3/3
replace q3=0 in 1/2
replace q3=0 in 4/4
replace q1=q1[_n-4] in 5/l
replace q2=q2[_n-4] in 5/l
replace q3=q3[_n-4] in 5/l

g lifs99=log(ifs99)
label var lifs99 "Log of ifs99"
g tlifs99=.
label var tlifs99 "Time de-trended log of ifs99"
g hlifs99=.
label var hlifs99 "HP de-trended log of ifs99"
g slifs99=.
label var slifs99 "HP de-trended log of SA ifs99"
sort ifscode date

g lifs66=log(ifs66)
label var lifs66 "Log of ifs66"
g tlifs66=.
label var tlifs66 "Time de-trended log of ifs66"
g hlifs66=.
label var hlifs66 "HP de-trended log of ifs66"
g slifs66=.
label var slifs66 "HP de-trended log of SA ifs66"
sort ifscode date

g let=log(et)
label var let "Log of et"
g tlet=.
label var tlet "Time de-trended log of et"
g hlet=.
label var hlet "HP de-trended log of et"
g slet=.
label var slet "HP de-trended log of SA et
sort ifscode date

g tunr=.
label var tunr "Time de-trended unr"
g hunr=.
label var hunr "HP de-trended unr"
g sunr=.
label var sunr "HP de-trended SA unr"
sort ifscode date
*
* Do the quadratic de-trending and HP de-trending on the natural logs.
*
* The country is 111
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
replace tlifs99=100.*crap if ifscode==111
drop crap

hpfilter lifs99 if ifscode==111
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==111
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
hpfilter crap if ifscode==111, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==111
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
replace tlifs66=100.*crap if ifscode==111
drop crap

hpfilter lifs66 if ifscode==111
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==111
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
hpfilter crap if ifscode==111, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==111
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
replace tlet=100.*crap if ifscode==111
drop crap

hpfilter let if ifscode==111
replace hlet=100.*(let-H.let) if ifscode==111
drop H.let

quietly reg let q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
hpfilter crap if ifscode==111, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==111
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
replace tunr=100.*crap if ifscode==111
drop crap

hpfilter unr if ifscode==111
replace hunr=100.*(unr-H.unr) if ifscode==111
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==111
predict crap if ifscode==111, residuals
hpfilter crap if ifscode==111, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==111
drop crap H.crap
*
* The country is 112
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
replace tlifs99=100.*crap if ifscode==112
drop crap

hpfilter lifs99 if ifscode==112
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==112
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
hpfilter crap if ifscode==112, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==112
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
replace tlifs66=100.*crap if ifscode==112
drop crap

hpfilter lifs66 if ifscode==112
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==112
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
hpfilter crap if ifscode==112, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==112
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
replace tlet=100.*crap if ifscode==112
drop crap

hpfilter let if ifscode==112
replace hlet=100.*(let-H.let) if ifscode==112
drop H.let

quietly reg let q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
hpfilter crap if ifscode==112, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==112
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
replace tunr=100.*crap if ifscode==112
drop crap

hpfilter unr if ifscode==112
replace hunr=100.*(unr-H.unr) if ifscode==112
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==112
predict crap if ifscode==112, residuals
hpfilter crap if ifscode==112, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==112
drop crap H.crap
*
* The country is 122
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
replace tlifs99=100.*crap if ifscode==122
drop crap

hpfilter lifs99 if ifscode==122
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==122
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
hpfilter crap if ifscode==122, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==122
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
replace tlifs66=100.*crap if ifscode==122
drop crap

hpfilter lifs66 if ifscode==122
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==122
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
hpfilter crap if ifscode==122, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==122
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
replace tlet=100.*crap if ifscode==122
drop crap

hpfilter let if ifscode==122
replace hlet=100.*(let-H.let) if ifscode==122
drop H.let

quietly reg let q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
hpfilter crap if ifscode==122, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==122
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
replace tunr=100.*crap if ifscode==122
drop crap

hpfilter unr if ifscode==122
replace hunr=100.*(unr-H.unr) if ifscode==122
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==122
predict crap if ifscode==122, residuals
hpfilter crap if ifscode==122, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==122
drop crap H.crap
*
* The country is 124
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
replace tlifs99=100.*crap if ifscode==124
drop crap

hpfilter lifs99 if ifscode==124
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==124
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
hpfilter crap if ifscode==124, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==124
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
replace tlifs66=100.*crap if ifscode==124
drop crap

hpfilter lifs66 if ifscode==124
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==124
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
hpfilter crap if ifscode==124, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==124
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
replace tlet=100.*crap if ifscode==124
drop crap

hpfilter let if ifscode==124
replace hlet=100.*(let-H.let) if ifscode==124
drop H.let

quietly reg let q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
hpfilter crap if ifscode==124, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==124
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
replace tunr=100.*crap if ifscode==124
drop crap

hpfilter unr if ifscode==124
replace hunr=100.*(unr-H.unr) if ifscode==124
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==124
predict crap if ifscode==124, residuals
hpfilter crap if ifscode==124, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==124
drop crap H.crap
*
* The country is 128
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
replace tlifs99=100.*crap if ifscode==128
drop crap

hpfilter lifs99 if ifscode==128
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==128
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
hpfilter crap if ifscode==128, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==128
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
replace tlifs66=100.*crap if ifscode==128
drop crap

hpfilter lifs66 if ifscode==128
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==128
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
hpfilter crap if ifscode==128, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==128
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
replace tlet=100.*crap if ifscode==128
drop crap

hpfilter let if ifscode==128
replace hlet=100.*(let-H.let) if ifscode==128
drop H.let

quietly reg let q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
hpfilter crap if ifscode==128, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==128
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
replace tunr=100.*crap if ifscode==128
drop crap

hpfilter unr if ifscode==128
replace hunr=100.*(unr-H.unr) if ifscode==128
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==128
predict crap if ifscode==128, residuals
hpfilter crap if ifscode==128, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==128
drop crap H.crap
*
* The country is 132
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
replace tlifs99=100.*crap if ifscode==132
drop crap

hpfilter lifs99 if ifscode==132
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==132
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
hpfilter crap if ifscode==132, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==132
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
replace tlifs66=100.*crap if ifscode==132
drop crap

hpfilter lifs66 if ifscode==132
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==132
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
hpfilter crap if ifscode==132, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==132
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
replace tlet=100.*crap if ifscode==132
drop crap

hpfilter let if ifscode==132
replace hlet=100.*(let-H.let) if ifscode==132
drop H.let

quietly reg let q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
hpfilter crap if ifscode==132, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==132
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
replace tunr=100.*crap if ifscode==132
drop crap

hpfilter unr if ifscode==132
replace hunr=100.*(unr-H.unr) if ifscode==132
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==132
predict crap if ifscode==132, residuals
hpfilter crap if ifscode==132, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==132
drop crap H.crap
*
* The country is 134
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
replace tlifs99=100.*crap if ifscode==134
drop crap

hpfilter lifs99 if ifscode==134
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==134
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
hpfilter crap if ifscode==134, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==134
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
replace tlifs66=100.*crap if ifscode==134
drop crap

hpfilter lifs66 if ifscode==134
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==134
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
hpfilter crap if ifscode==134, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==134
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
replace tlet=100.*crap if ifscode==134
drop crap

hpfilter let if ifscode==134
replace hlet=100.*(let-H.let) if ifscode==134
drop H.let

quietly reg let q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
hpfilter crap if ifscode==134, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==134
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
replace tunr=100.*crap if ifscode==134
drop crap

hpfilter unr if ifscode==134
replace hunr=100.*(unr-H.unr) if ifscode==134
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==134
predict crap if ifscode==134, residuals
hpfilter crap if ifscode==134, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==134
drop crap H.crap
*
* The country is 136
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
replace tlifs99=100.*crap if ifscode==136
drop crap

hpfilter lifs99 if ifscode==136
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==136
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
hpfilter crap if ifscode==136, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==136
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
replace tlifs66=100.*crap if ifscode==136
drop crap

hpfilter lifs66 if ifscode==136
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==136
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
hpfilter crap if ifscode==136, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==136
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
replace tlet=100.*crap if ifscode==136
drop crap

hpfilter let if ifscode==136
replace hlet=100.*(let-H.let) if ifscode==136
drop H.let

quietly reg let q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
hpfilter crap if ifscode==136, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==136
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
replace tunr=100.*crap if ifscode==136
drop crap

hpfilter unr if ifscode==136
replace hunr=100.*(unr-H.unr) if ifscode==136
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==136
predict crap if ifscode==136, residuals
hpfilter crap if ifscode==136, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==136
drop crap H.crap
*
* The country is 138
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
replace tlifs99=100.*crap if ifscode==138
drop crap

hpfilter lifs99 if ifscode==138
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==138
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
hpfilter crap if ifscode==138, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==138
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
replace tlifs66=100.*crap if ifscode==138
drop crap

hpfilter lifs66 if ifscode==138
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==138
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
hpfilter crap if ifscode==138, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==138
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
replace tlet=100.*crap if ifscode==138
drop crap

hpfilter let if ifscode==138
replace hlet=100.*(let-H.let) if ifscode==138
drop H.let

quietly reg let q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
hpfilter crap if ifscode==138, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==138
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
replace tunr=100.*crap if ifscode==138
drop crap

hpfilter unr if ifscode==138
replace hunr=100.*(unr-H.unr) if ifscode==138
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==138
predict crap if ifscode==138, residuals
hpfilter crap if ifscode==138, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==138
drop crap H.crap
*
* The country is 142
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
replace tlifs99=100.*crap if ifscode==142
drop crap

hpfilter lifs99 if ifscode==142
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==142
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
hpfilter crap if ifscode==142, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==142
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
replace tlifs66=100.*crap if ifscode==142
drop crap

hpfilter lifs66 if ifscode==142
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==142
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
hpfilter crap if ifscode==142, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==142
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
replace tlet=100.*crap if ifscode==142
drop crap

hpfilter let if ifscode==142
replace hlet=100.*(let-H.let) if ifscode==142
drop H.let

quietly reg let q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
hpfilter crap if ifscode==142, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==142
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
replace tunr=100.*crap if ifscode==142
drop crap

hpfilter unr if ifscode==142
replace hunr=100.*(unr-H.unr) if ifscode==142
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==142
predict crap if ifscode==142, residuals
hpfilter crap if ifscode==142, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==142
drop crap H.crap
*
* The country is 144
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
replace tlifs99=100.*crap if ifscode==144
drop crap

hpfilter lifs99 if ifscode==144
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==144
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
hpfilter crap if ifscode==144, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==144
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
replace tlifs66=100.*crap if ifscode==144
drop crap

hpfilter lifs66 if ifscode==144
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==144
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
hpfilter crap if ifscode==144, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==144
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
replace tlet=100.*crap if ifscode==144
drop crap

hpfilter let if ifscode==144
replace hlet=100.*(let-H.let) if ifscode==144
drop H.let

quietly reg let q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
hpfilter crap if ifscode==144, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==144
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
replace tunr=100.*crap if ifscode==144
drop crap

hpfilter unr if ifscode==144
replace hunr=100.*(unr-H.unr) if ifscode==144
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==144
predict crap if ifscode==144, residuals
hpfilter crap if ifscode==144, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==144
drop crap H.crap
*
* The country is 146
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
replace tlifs99=100.*crap if ifscode==146
drop crap

hpfilter lifs99 if ifscode==146
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==146
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
hpfilter crap if ifscode==146, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==146
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
replace tlifs66=100.*crap if ifscode==146
drop crap

hpfilter lifs66 if ifscode==146
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==146
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
hpfilter crap if ifscode==146, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==146
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
replace tlet=100.*crap if ifscode==146
drop crap

hpfilter let if ifscode==146
replace hlet=100.*(let-H.let) if ifscode==146
drop H.let

quietly reg let q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
hpfilter crap if ifscode==146, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==146
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
replace tunr=100.*crap if ifscode==146
drop crap

hpfilter unr if ifscode==146
replace hunr=100.*(unr-H.unr) if ifscode==146
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==146
predict crap if ifscode==146, residuals
hpfilter crap if ifscode==146, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==146
drop crap H.crap
*
* The country is 156
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
replace tlifs99=100.*crap if ifscode==156
drop crap

hpfilter lifs99 if ifscode==156
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==156
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
hpfilter crap if ifscode==156, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==156
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
replace tlifs66=100.*crap if ifscode==156
drop crap

hpfilter lifs66 if ifscode==156
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==156
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
hpfilter crap if ifscode==156, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==156
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
replace tlet=100.*crap if ifscode==156
drop crap

hpfilter let if ifscode==156
replace hlet=100.*(let-H.let) if ifscode==156
drop H.let

quietly reg let q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
hpfilter crap if ifscode==156, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==156
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
replace tunr=100.*crap if ifscode==156
drop crap

hpfilter unr if ifscode==156
replace hunr=100.*(unr-H.unr) if ifscode==156
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==156
predict crap if ifscode==156, residuals
hpfilter crap if ifscode==156, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==156
drop crap H.crap
*
* The country is 158
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
replace tlifs99=100.*crap if ifscode==158
drop crap

hpfilter lifs99 if ifscode==158
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==158
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
hpfilter crap if ifscode==158, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==158
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
replace tlifs66=100.*crap if ifscode==158
drop crap

hpfilter lifs66 if ifscode==158
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==158
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
hpfilter crap if ifscode==158, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==158
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
replace tlet=100.*crap if ifscode==158
drop crap

hpfilter let if ifscode==158
replace hlet=100.*(let-H.let) if ifscode==158
drop H.let

quietly reg let q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
hpfilter crap if ifscode==158, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==158
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
replace tunr=100.*crap if ifscode==158
drop crap

hpfilter unr if ifscode==158
replace hunr=100.*(unr-H.unr) if ifscode==158
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==158
predict crap if ifscode==158, residuals
hpfilter crap if ifscode==158, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==158
drop crap H.crap
*
* The country is 172
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
replace tlifs99=100.*crap if ifscode==172
drop crap

hpfilter lifs99 if ifscode==172
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==172
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
hpfilter crap if ifscode==172, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==172
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
replace tlifs66=100.*crap if ifscode==172
drop crap

hpfilter lifs66 if ifscode==172
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==172
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
hpfilter crap if ifscode==172, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==172
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
replace tlet=100.*crap if ifscode==172
drop crap

hpfilter let if ifscode==172
replace hlet=100.*(let-H.let) if ifscode==172
drop H.let

quietly reg let q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
hpfilter crap if ifscode==172, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==172
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
replace tunr=100.*crap if ifscode==172
drop crap

hpfilter unr if ifscode==172
replace hunr=100.*(unr-H.unr) if ifscode==172
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==172
predict crap if ifscode==172, residuals
hpfilter crap if ifscode==172, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==172
drop crap H.crap
*
* The country is 174
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
replace tlifs99=100.*crap if ifscode==174
drop crap

hpfilter lifs99 if ifscode==174
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==174
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
hpfilter crap if ifscode==174, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==174
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
replace tlifs66=100.*crap if ifscode==174
drop crap

hpfilter lifs66 if ifscode==174
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==174
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
hpfilter crap if ifscode==174, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==174
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
replace tlet=100.*crap if ifscode==174
drop crap

hpfilter let if ifscode==174
replace hlet=100.*(let-H.let) if ifscode==174
drop H.let

quietly reg let q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
hpfilter crap if ifscode==174, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==174
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
replace tunr=100.*crap if ifscode==174
drop crap

hpfilter unr if ifscode==174
replace hunr=100.*(unr-H.unr) if ifscode==174
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==174
predict crap if ifscode==174, residuals
hpfilter crap if ifscode==174, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==174
drop crap H.crap
*
* The country is 176
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==176
predict crap if ifscode==176, residuals
replace tlifs99=100.*crap if ifscode==176
drop crap

hpfilter lifs99 if ifscode==176
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==176
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==176
predict crap if ifscode==176, residuals
hpfilter crap if ifscode==176, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==176
drop crap H.crap
*
* The country is 178
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
replace tlifs99=100.*crap if ifscode==178
drop crap

hpfilter lifs99 if ifscode==178
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==178
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
hpfilter crap if ifscode==178, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==178
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
replace tlifs66=100.*crap if ifscode==178
drop crap

hpfilter lifs66 if ifscode==178
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==178
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
hpfilter crap if ifscode==178, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==178
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
replace tlet=100.*crap if ifscode==178
drop crap

hpfilter let if ifscode==178
replace hlet=100.*(let-H.let) if ifscode==178
drop H.let

quietly reg let q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
hpfilter crap if ifscode==178, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==178
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
replace tunr=100.*crap if ifscode==178
drop crap

hpfilter unr if ifscode==178
replace hunr=100.*(unr-H.unr) if ifscode==178
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==178
predict crap if ifscode==178, residuals
hpfilter crap if ifscode==178, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==178
drop crap H.crap
*
* The country is 181
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==181
predict crap if ifscode==181, residuals
replace tlifs99=100.*crap if ifscode==181
drop crap

hpfilter lifs99 if ifscode==181
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==181
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==181
predict crap if ifscode==181, residuals
hpfilter crap if ifscode==181, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==181
drop crap H.crap
*
* The country is 182
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==182
predict crap if ifscode==182, residuals
replace tlifs99=100.*crap if ifscode==182
drop crap

hpfilter lifs99 if ifscode==182
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==182
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==182
predict crap if ifscode==182, residuals
hpfilter crap if ifscode==182, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==182
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==182
predict crap if ifscode==182, residuals
replace tlet=100.*crap if ifscode==182
drop crap

hpfilter let if ifscode==182
replace hlet=100.*(let-H.let) if ifscode==182
drop H.let

quietly reg let q1 q2 q3 if ifscode==182
predict crap if ifscode==182, residuals
hpfilter crap if ifscode==182, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==182
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==182
predict crap if ifscode==182, residuals
replace tunr=100.*crap if ifscode==182
drop crap

hpfilter unr if ifscode==182
replace hunr=100.*(unr-H.unr) if ifscode==182
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==182
predict crap if ifscode==182, residuals
hpfilter crap if ifscode==182, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==182
drop crap H.crap
*
* The country is 184
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
replace tlifs99=100.*crap if ifscode==184
drop crap

hpfilter lifs99 if ifscode==184
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==184
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
hpfilter crap if ifscode==184, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==184
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
replace tlifs66=100.*crap if ifscode==184
drop crap

hpfilter lifs66 if ifscode==184
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==184
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
hpfilter crap if ifscode==184, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==184
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
replace tlet=100.*crap if ifscode==184
drop crap

hpfilter let if ifscode==184
replace hlet=100.*(let-H.let) if ifscode==184
drop H.let

quietly reg let q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
hpfilter crap if ifscode==184, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==184
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
replace tunr=100.*crap if ifscode==184
drop crap

hpfilter unr if ifscode==184
replace hunr=100.*(unr-H.unr) if ifscode==184
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==184
predict crap if ifscode==184, residuals
hpfilter crap if ifscode==184, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==184
drop crap H.crap
*
* The country is 186
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==186
predict crap if ifscode==186, residuals
replace tlifs99=100.*crap if ifscode==186
drop crap

hpfilter lifs99 if ifscode==186
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==186
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==186
predict crap if ifscode==186, residuals
hpfilter crap if ifscode==186, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==186
drop crap H.crap
*
* The country is 193
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
replace tlifs99=100.*crap if ifscode==193
drop crap

hpfilter lifs99 if ifscode==193
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==193
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
hpfilter crap if ifscode==193, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==193
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
replace tlifs66=100.*crap if ifscode==193
drop crap

hpfilter lifs66 if ifscode==193
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==193
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
hpfilter crap if ifscode==193, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==193
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
replace tlet=100.*crap if ifscode==193
drop crap

hpfilter let if ifscode==193
replace hlet=100.*(let-H.let) if ifscode==193
drop H.let

quietly reg let q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
hpfilter crap if ifscode==193, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==193
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
replace tunr=100.*crap if ifscode==193
drop crap

hpfilter unr if ifscode==193
replace hunr=100.*(unr-H.unr) if ifscode==193
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==193
predict crap if ifscode==193, residuals
hpfilter crap if ifscode==193, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==193
drop crap H.crap
*
* The country is 196
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
replace tlifs99=100.*crap if ifscode==196
drop crap

hpfilter lifs99 if ifscode==196
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==196
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
hpfilter crap if ifscode==196, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==196
drop crap H.crap


quietly reg lifs66 time timesq q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
replace tlifs66=100.*crap if ifscode==196
drop crap

hpfilter lifs66 if ifscode==196
replace hlifs66=100.*(lifs66-H.lifs66) if ifscode==196
drop H.lifs66

quietly reg lifs66 q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
hpfilter crap if ifscode==196, l(1600)
replace slifs66=100.*(crap-H.crap) if ifscode==196
drop crap H.crap


quietly reg let time timesq q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
replace tlet=100.*crap if ifscode==196
drop crap

hpfilter let if ifscode==196
replace hlet=100.*(let-H.let) if ifscode==196
drop H.let

quietly reg let q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
hpfilter crap if ifscode==196, l(1600)
replace slet=100.*(crap-H.crap) if ifscode==196
drop crap H.crap


quietly reg unr time timesq q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
replace tunr=100.*crap if ifscode==196
drop crap

hpfilter unr if ifscode==196
replace hunr=100.*(unr-H.unr) if ifscode==196
drop H.unr

quietly reg unr q1 q2 q3 if ifscode==196
predict crap if ifscode==196, residuals
hpfilter crap if ifscode==196, l(1600)
replace sunr=100.*(crap-H.crap) if ifscode==196
drop crap H.crap
*
* The country is 199
*
quietly reg lifs99 time timesq q1 q2 q3 if ifscode==199
predict crap if ifscode==199, residuals
replace tlifs99=100.*crap if ifscode==199
drop crap

hpfilter lifs99 if ifscode==199
replace hlifs99=100.*(lifs99-H.lifs99) if ifscode==199
drop H.lifs99

quietly reg lifs99 q1 q2 q3 if ifscode==199
predict crap if ifscode==199, residuals
hpfilter crap if ifscode==199, l(1600)
replace slifs99=100.*(crap-H.crap) if ifscode==199
drop crap H.crap
*
* Save it
*
drop time timesq q1 q2 q3
compress
sort ifscode date
save \res\oca\data\datav2,replace
*
* Close Down
*
drop _all
log close
exit,clear
