drop _all
program drop _all
log using datav3,replace
*
* This STATA transforms the panel data set DATAV2 into a bilateral data set.
*
set more 1
set maxobs 4000
*
* First the trade density weights are computed and written out
*
* Read in the data and clean it up
*
use \res\oca\data\datav2a
drop if ifscode==199
drop if ifscode==186
drop if ifscode==181
drop if ifscode==176
*
* Compute the weights
*
g wxas=exptoas/(asexp+totexp)
g wxau=exptoau/(auexp+totexp)
g wxbe=exptobe/(beexp+totexp)
g wxca=exptoca/(caexp+totexp)
g wxde=exptode/(deexp+totexp)
g wxfi=exptofi/(fiexp+totexp)
g wxfr=exptofr/(frexp+totexp)
g wxgc=exptogc/(gcexp+totexp)
g wxgr=exptogr/(grexp+totexp)
g wxir=exptoir/(irexp+totexp)
g wxit=exptoit/(itexp+totexp)
g wxja=exptoja/(jaexp+totexp)
g wxno=exptono/(noexp+totexp)
g wxnt=exptont/(ntexp+totexp)
g wxnz=exptonz/(nzexp+totexp)
g wxpo=exptopo/(poexp+totexp)
g wxsp=exptosp/(spexp+totexp)
g wxsw=exptosw/(swexp+totexp)
g wxsz=exptosz/(szexp+totexp)
g wxuk=exptouk/(ukexp+totexp)
g wxus=exptous/(usexp+totexp)

g wmas=impfras/(asimp+totimp)
g wmau=impfrau/(auimp+totimp)
g wmbe=impfrbe/(beimp+totimp)
g wmca=impfrca/(caimp+totimp)
g wmde=impfrde/(deimp+totimp)
g wmfi=impfrfi/(fiimp+totimp)
g wmfr=impfrfr/(frimp+totimp)
g wmgc=impfrgc/(gcimp+totimp)
g wmgr=impfrgr/(grimp+totimp)
g wmir=impfrir/(irimp+totimp)
g wmit=impfrit/(itimp+totimp)
g wmja=impfrja/(jaimp+totimp)
g wmno=impfrno/(noimp+totimp)
g wmnt=impfrnt/(ntimp+totimp)
g wmnz=impfrnz/(nzimp+totimp)
g wmpo=impfrpo/(poimp+totimp)
g wmsp=impfrsp/(spimp+totimp)
g wmsw=impfrsw/(swimp+totimp)
g wmsz=impfrsz/(szimp+totimp)
g wmuk=impfruk/(ukimp+totimp)
g wmus=impfrus/(usimp+totimp)

g wtas=(exptoas+impfras)/(totimp+totexp+asimp+asexp)
g wtau=(exptoau+impfrau)/(totimp+totexp+auimp+auexp)
g wtbe=(exptobe+impfrbe)/(totimp+totexp+beimp+beexp)
g wtca=(exptoca+impfrca)/(totimp+totexp+caimp+caexp)
g wtde=(exptode+impfrde)/(totimp+totexp+deimp+deexp)
g wtfi=(exptofi+impfrfi)/(totimp+totexp+fiimp+fiexp)
g wtfr=(exptofr+impfrfr)/(totimp+totexp+frimp+frexp)
g wtgc=(exptogc+impfrgc)/(totimp+totexp+gcimp+gcexp)
g wtgr=(exptogr+impfrgr)/(totimp+totexp+grimp+grexp)
g wtir=(exptoir+impfrir)/(totimp+totexp+irimp+irexp)
g wtit=(exptoit+impfrit)/(totimp+totexp+itimp+itexp)
g wtja=(exptoja+impfrja)/(totimp+totexp+jaimp+jaexp)
g wtno=(exptono+impfrno)/(totimp+totexp+noimp+noexp)
g wtnt=(exptont+impfrnt)/(totimp+totexp+ntimp+ntexp)
g wtnz=(exptonz+impfrnz)/(totimp+totexp+nzimp+nzexp)
g wtpo=(exptopo+impfrpo)/(totimp+totexp+poimp+poexp)
g wtsp=(exptosp+impfrsp)/(totimp+totexp+spimp+spexp)
g wtsw=(exptosw+impfrsw)/(totimp+totexp+swimp+swexp)
g wtsz=(exptosz+impfrsz)/(totimp+totexp+szimp+szexp)
g wtuk=(exptouk+impfruk)/(totimp+totexp+ukimp+ukexp)
g wtus=(exptous+impfrus)/(totimp+totexp+usimp+usexp)
*
* Create the bilateral trade weights (empty): eXport,iMport or total Trade.
*
g wx=.
g wm=.
g wt=.

label var wx "Average Bilateral Export Importance"
label var wm "Average Bilateral Import Importance"
label var wt "Average Bilateral Trade Importance"

g count1=.
g count2=.

label var count1 "Exporter or Importer"
label var count2 "Exportee or Import Sender"
*
* Copy and rename the weights (for the program)
*
g wx111=wxus
g wx112=wxuk
g wx122=wxau
g wx124=wxbe
g wx128=wxde
g wx132=wxfr
g wx134=wxgr
g wx136=wxit
g wx138=wxnt
g wx142=wxno
g wx144=wxsw
g wx146=wxsz
g wx156=wxca
g wx158=wxja
g wx172=wxfi
g wx174=wxgc
g wx178=wxir
g wx182=wxpo
g wx184=wxsp
g wx193=wxas
g wx196=wxnz

g wm111=wmus
g wm112=wmuk
g wm122=wmau
g wm124=wmbe
g wm128=wmde
g wm132=wmfr
g wm134=wmgr
g wm136=wmit
g wm138=wmnt
g wm142=wmno
g wm144=wmsw
g wm146=wmsz
g wm156=wmca
g wm158=wmja
g wm172=wmfi
g wm174=wmgc
g wm178=wmir
g wm182=wmpo
g wm184=wmsp
g wm193=wmas
g wm196=wmnz

g wt111=wtus
g wt112=wtuk
g wt122=wtau
g wt124=wtbe
g wt128=wtde
g wt132=wtfr
g wt134=wtgr
g wt136=wtit
g wt138=wtnt
g wt142=wtno
g wt144=wtsw
g wt146=wtsz
g wt156=wtca
g wt158=wtja
g wt172=wtfi
g wt174=wtgc
g wt178=wtir
g wt182=wtpo
g wt184=wtsp
g wt193=wtas
g wt196=wtnz
*
* A program to compute average weights
*
program define prog1 /* country1 country2 start end obs*/
	quietly replace count1=`1' in `5'/`5'
	quietly replace count2=`2' in `5'/`5'
	quietly sum wx`2' if ifscode==`1'&(date>`3'&date<`4')
	quietly replace wx=_result(3) in `5'/`5'
	quietly sum wm`2' if ifscode==`1'&(date>`3'&date<`4')
	quietly replace wm=_result(3) in `5'/`5'
	quietly sum wt`2' if ifscode==`1'&(date>`3'&date<`4')
	quietly replace wt=_result(3) in `5'/`5'
	end
*
* Compute the weights
*
prog1 111 112 1950.05 1967.35 1
prog1 111 122 1950.05 1967.35 2
prog1 111 124 1950.05 1967.35 3
prog1 111 128 1950.05 1967.35 4
prog1 111 132 1950.05 1967.35 5
prog1 111 134 1950.05 1967.35 6
prog1 111 136 1950.05 1967.35 7
prog1 111 138 1950.05 1967.35 8
prog1 111 142 1950.05 1967.35 9
prog1 111 144 1950.05 1967.35 10
prog1 111 146 1950.05 1967.35 11
prog1 111 156 1950.05 1967.35 12
prog1 111 158 1950.05 1967.35 13
prog1 111 172 1950.05 1967.35 14
prog1 111 174 1950.05 1967.35 15
prog1 111 178 1950.05 1967.35 16
prog1 111 182 1950.05 1967.35 17
prog1 111 184 1950.05 1967.35 18
prog1 111 193 1950.05 1967.35 19
prog1 111 196 1950.05 1967.35 20
prog1 112 122 1950.05 1967.35 21
prog1 112 124 1950.05 1967.35 22
prog1 112 128 1950.05 1967.35 23
prog1 112 132 1950.05 1967.35 24
prog1 112 134 1950.05 1967.35 25
prog1 112 136 1950.05 1967.35 26
prog1 112 138 1950.05 1967.35 27
prog1 112 142 1950.05 1967.35 28
prog1 112 144 1950.05 1967.35 29
prog1 112 146 1950.05 1967.35 30
prog1 112 156 1950.05 1967.35 31
prog1 112 158 1950.05 1967.35 32
prog1 112 172 1950.05 1967.35 33
prog1 112 174 1950.05 1967.35 34
prog1 112 178 1950.05 1967.35 35
prog1 112 182 1950.05 1967.35 36
prog1 112 184 1950.05 1967.35 37
prog1 112 193 1950.05 1967.35 38
prog1 112 196 1950.05 1967.35 39
prog1 122 124 1950.05 1967.35 40
prog1 122 128 1950.05 1967.35 41
prog1 122 132 1950.05 1967.35 42
prog1 122 134 1950.05 1967.35 43
prog1 122 136 1950.05 1967.35 44
prog1 122 138 1950.05 1967.35 45
prog1 122 142 1950.05 1967.35 46
prog1 122 144 1950.05 1967.35 47
prog1 122 146 1950.05 1967.35 48
prog1 122 156 1950.05 1967.35 49
prog1 122 158 1950.05 1967.35 50
prog1 122 172 1950.05 1967.35 51
prog1 122 174 1950.05 1967.35 52
prog1 122 178 1950.05 1967.35 53
prog1 122 182 1950.05 1967.35 54
prog1 122 184 1950.05 1967.35 55
prog1 122 193 1950.05 1967.35 56
prog1 122 196 1950.05 1967.35 57
prog1 124 128 1950.05 1967.35 58
prog1 124 132 1950.05 1967.35 59
prog1 124 134 1950.05 1967.35 60
prog1 124 136 1950.05 1967.35 61
prog1 124 138 1950.05 1967.35 62
prog1 124 142 1950.05 1967.35 63
prog1 124 144 1950.05 1967.35 64
prog1 124 146 1950.05 1967.35 65
prog1 124 156 1950.05 1967.35 66
prog1 124 158 1950.05 1967.35 67
prog1 124 172 1950.05 1967.35 68
prog1 124 174 1950.05 1967.35 69
prog1 124 178 1950.05 1967.35 70
prog1 124 182 1950.05 1967.35 71
prog1 124 184 1950.05 1967.35 72
prog1 124 193 1950.05 1967.35 73
prog1 124 196 1950.05 1967.35 74
prog1 128 132 1950.05 1967.35 75
prog1 128 134 1950.05 1967.35 76
prog1 128 136 1950.05 1967.35 77
prog1 128 138 1950.05 1967.35 78
prog1 128 142 1950.05 1967.35 79
prog1 128 144 1950.05 1967.35 80
prog1 128 146 1950.05 1967.35 81
prog1 128 156 1950.05 1967.35 82
prog1 128 158 1950.05 1967.35 83
prog1 128 172 1950.05 1967.35 84
prog1 128 174 1950.05 1967.35 85
prog1 128 178 1950.05 1967.35 86
prog1 128 182 1950.05 1967.35 87
prog1 128 184 1950.05 1967.35 88
prog1 128 193 1950.05 1967.35 89
prog1 128 196 1950.05 1967.35 90
prog1 132 134 1950.05 1967.35 91
prog1 132 136 1950.05 1967.35 92
prog1 132 138 1950.05 1967.35 93
prog1 132 142 1950.05 1967.35 94
prog1 132 144 1950.05 1967.35 95
prog1 132 146 1950.05 1967.35 96
prog1 132 156 1950.05 1967.35 97
prog1 132 158 1950.05 1967.35 98
prog1 132 172 1950.05 1967.35 99
prog1 132 174 1950.05 1967.35 100
prog1 132 178 1950.05 1967.35 101
prog1 132 182 1950.05 1967.35 102
prog1 132 184 1950.05 1967.35 103
prog1 132 193 1950.05 1967.35 104
prog1 132 196 1950.05 1967.35 105
prog1 134 136 1950.05 1967.35 106
prog1 134 138 1950.05 1967.35 107
prog1 134 142 1950.05 1967.35 108
prog1 134 144 1950.05 1967.35 109
prog1 134 146 1950.05 1967.35 110
prog1 134 156 1950.05 1967.35 111
prog1 134 158 1950.05 1967.35 112
prog1 134 172 1950.05 1967.35 113
prog1 134 174 1950.05 1967.35 114
prog1 134 178 1950.05 1967.35 115
prog1 134 182 1950.05 1967.35 116
prog1 134 184 1950.05 1967.35 117
prog1 134 193 1950.05 1967.35 118
prog1 134 196 1950.05 1967.35 119
prog1 136 138 1950.05 1967.35 120
prog1 136 142 1950.05 1967.35 121
prog1 136 144 1950.05 1967.35 122
prog1 136 146 1950.05 1967.35 123
prog1 136 156 1950.05 1967.35 124
prog1 136 158 1950.05 1967.35 125
prog1 136 172 1950.05 1967.35 126
prog1 136 174 1950.05 1967.35 127
prog1 136 178 1950.05 1967.35 128
prog1 136 182 1950.05 1967.35 129
prog1 136 184 1950.05 1967.35 130
prog1 136 193 1950.05 1967.35 131
prog1 136 196 1950.05 1967.35 132
prog1 138 142 1950.05 1967.35 133
prog1 138 144 1950.05 1967.35 134
prog1 138 146 1950.05 1967.35 135
prog1 138 156 1950.05 1967.35 136
prog1 138 158 1950.05 1967.35 137
prog1 138 172 1950.05 1967.35 138
prog1 138 174 1950.05 1967.35 139
prog1 138 178 1950.05 1967.35 140
prog1 138 182 1950.05 1967.35 141
prog1 138 184 1950.05 1967.35 142
prog1 138 193 1950.05 1967.35 143
prog1 138 196 1950.05 1967.35 144
prog1 142 144 1950.05 1967.35 145
prog1 142 146 1950.05 1967.35 146
prog1 142 156 1950.05 1967.35 147
prog1 142 158 1950.05 1967.35 148
prog1 142 172 1950.05 1967.35 149
prog1 142 174 1950.05 1967.35 150
prog1 142 178 1950.05 1967.35 151
prog1 142 182 1950.05 1967.35 152
prog1 142 184 1950.05 1967.35 153
prog1 142 193 1950.05 1967.35 154
prog1 142 196 1950.05 1967.35 155
prog1 144 146 1950.05 1967.35 156
prog1 144 156 1950.05 1967.35 157
prog1 144 158 1950.05 1967.35 158
prog1 144 172 1950.05 1967.35 159
prog1 144 174 1950.05 1967.35 160
prog1 144 178 1950.05 1967.35 161
prog1 144 182 1950.05 1967.35 162
prog1 144 184 1950.05 1967.35 163
prog1 144 193 1950.05 1967.35 164
prog1 144 196 1950.05 1967.35 165
prog1 146 156 1950.05 1967.35 166
prog1 146 158 1950.05 1967.35 167
prog1 146 172 1950.05 1967.35 168
prog1 146 174 1950.05 1967.35 169
prog1 146 178 1950.05 1967.35 170
prog1 146 182 1950.05 1967.35 171
prog1 146 184 1950.05 1967.35 172
prog1 146 193 1950.05 1967.35 173
prog1 146 196 1950.05 1967.35 174
prog1 156 158 1950.05 1967.35 175
prog1 156 172 1950.05 1967.35 176
prog1 156 174 1950.05 1967.35 177
prog1 156 178 1950.05 1967.35 178
prog1 156 182 1950.05 1967.35 179
prog1 156 184 1950.05 1967.35 180
prog1 156 193 1950.05 1967.35 181
prog1 156 196 1950.05 1967.35 182
prog1 158 172 1950.05 1967.35 183
prog1 158 174 1950.05 1967.35 184
prog1 158 178 1950.05 1967.35 185
prog1 158 182 1950.05 1967.35 186
prog1 158 184 1950.05 1967.35 187
prog1 158 193 1950.05 1967.35 188
prog1 158 196 1950.05 1967.35 189
prog1 172 174 1950.05 1967.35 190
prog1 172 178 1950.05 1967.35 191
prog1 172 182 1950.05 1967.35 192
prog1 172 184 1950.05 1967.35 193
prog1 172 193 1950.05 1967.35 194
prog1 172 196 1950.05 1967.35 195
prog1 174 178 1950.05 1967.35 196
prog1 174 182 1950.05 1967.35 197
prog1 174 184 1950.05 1967.35 198
prog1 174 193 1950.05 1967.35 199
prog1 174 196 1950.05 1967.35 200
prog1 178 182 1950.05 1967.35 201
prog1 178 184 1950.05 1967.35 202
prog1 178 193 1950.05 1967.35 203
prog1 178 196 1950.05 1967.35 204
prog1 182 184 1950.05 1967.35 205
prog1 182 193 1950.05 1967.35 206
prog1 182 196 1950.05 1967.35 207
prog1 184 193 1950.05 1967.35 208
prog1 184 196 1950.05 1967.35 209
prog1 193 196 1950.05 1967.35 210

prog1 111 112 1967.35 1976.25 211
prog1 111 122 1967.35 1976.25 212
prog1 111 124 1967.35 1976.25 213
prog1 111 128 1967.35 1976.25 214
prog1 111 132 1967.35 1976.25 215
prog1 111 134 1967.35 1976.25 216
prog1 111 136 1967.35 1976.25 217
prog1 111 138 1967.35 1976.25 218
prog1 111 142 1967.35 1976.25 219
prog1 111 144 1967.35 1976.25 220
prog1 111 146 1967.35 1976.25 221
prog1 111 156 1967.35 1976.25 222
prog1 111 158 1967.35 1976.25 223
prog1 111 172 1967.35 1976.25 224
prog1 111 174 1967.35 1976.25 225
prog1 111 178 1967.35 1976.25 226
prog1 111 182 1967.35 1976.25 227
prog1 111 184 1967.35 1976.25 228
prog1 111 193 1967.35 1976.25 229
prog1 111 196 1967.35 1976.25 230
prog1 112 122 1967.35 1976.25 231
prog1 112 124 1967.35 1976.25 232
prog1 112 128 1967.35 1976.25 233
prog1 112 132 1967.35 1976.25 234
prog1 112 134 1967.35 1976.25 235
prog1 112 136 1967.35 1976.25 236
prog1 112 138 1967.35 1976.25 237
prog1 112 142 1967.35 1976.25 238
prog1 112 144 1967.35 1976.25 239
prog1 112 146 1967.35 1976.25 240
prog1 112 156 1967.35 1976.25 241
prog1 112 158 1967.35 1976.25 242
prog1 112 172 1967.35 1976.25 243
prog1 112 174 1967.35 1976.25 244
prog1 112 178 1967.35 1976.25 245
prog1 112 182 1967.35 1976.25 246
prog1 112 184 1967.35 1976.25 247
prog1 112 193 1967.35 1976.25 248
prog1 112 196 1967.35 1976.25 249
prog1 122 124 1967.35 1976.25 250
prog1 122 128 1967.35 1976.25 251
prog1 122 132 1967.35 1976.25 252
prog1 122 134 1967.35 1976.25 253
prog1 122 136 1967.35 1976.25 254
prog1 122 138 1967.35 1976.25 255
prog1 122 142 1967.35 1976.25 256
prog1 122 144 1967.35 1976.25 257
prog1 122 146 1967.35 1976.25 258
prog1 122 156 1967.35 1976.25 259
prog1 122 158 1967.35 1976.25 260
prog1 122 172 1967.35 1976.25 261
prog1 122 174 1967.35 1976.25 262
prog1 122 178 1967.35 1976.25 263
prog1 122 182 1967.35 1976.25 264
prog1 122 184 1967.35 1976.25 265
prog1 122 193 1967.35 1976.25 266
prog1 122 196 1967.35 1976.25 267
prog1 124 128 1967.35 1976.25 268
prog1 124 132 1967.35 1976.25 269
prog1 124 134 1967.35 1976.25 270
prog1 124 136 1967.35 1976.25 271
prog1 124 138 1967.35 1976.25 272
prog1 124 142 1967.35 1976.25 273
prog1 124 144 1967.35 1976.25 274
prog1 124 146 1967.35 1976.25 275
prog1 124 156 1967.35 1976.25 276
prog1 124 158 1967.35 1976.25 277
prog1 124 172 1967.35 1976.25 278
prog1 124 174 1967.35 1976.25 279
prog1 124 178 1967.35 1976.25 280
prog1 124 182 1967.35 1976.25 281
prog1 124 184 1967.35 1976.25 282
prog1 124 193 1967.35 1976.25 283
prog1 124 196 1967.35 1976.25 284
prog1 128 132 1967.35 1976.25 285
prog1 128 134 1967.35 1976.25 286
prog1 128 136 1967.35 1976.25 287
prog1 128 138 1967.35 1976.25 288
prog1 128 142 1967.35 1976.25 289
prog1 128 144 1967.35 1976.25 290
prog1 128 146 1967.35 1976.25 291
prog1 128 156 1967.35 1976.25 292
prog1 128 158 1967.35 1976.25 293
prog1 128 172 1967.35 1976.25 294
prog1 128 174 1967.35 1976.25 295
prog1 128 178 1967.35 1976.25 296
prog1 128 182 1967.35 1976.25 297
prog1 128 184 1967.35 1976.25 298
prog1 128 193 1967.35 1976.25 299
prog1 128 196 1967.35 1976.25 300
prog1 132 134 1967.35 1976.25 301
prog1 132 136 1967.35 1976.25 302
prog1 132 138 1967.35 1976.25 303
prog1 132 142 1967.35 1976.25 304
prog1 132 144 1967.35 1976.25 305
prog1 132 146 1967.35 1976.25 306
prog1 132 156 1967.35 1976.25 307
prog1 132 158 1967.35 1976.25 308
prog1 132 172 1967.35 1976.25 309
prog1 132 174 1967.35 1976.25 310
prog1 132 178 1967.35 1976.25 311
prog1 132 182 1967.35 1976.25 312
prog1 132 184 1967.35 1976.25 313
prog1 132 193 1967.35 1976.25 314
prog1 132 196 1967.35 1976.25 315
prog1 134 136 1967.35 1976.25 316
prog1 134 138 1967.35 1976.25 317
prog1 134 142 1967.35 1976.25 318
prog1 134 144 1967.35 1976.25 319
prog1 134 146 1967.35 1976.25 320
prog1 134 156 1967.35 1976.25 321
prog1 134 158 1967.35 1976.25 322
prog1 134 172 1967.35 1976.25 323
prog1 134 174 1967.35 1976.25 324
prog1 134 178 1967.35 1976.25 325
prog1 134 182 1967.35 1976.25 326
prog1 134 184 1967.35 1976.25 327
prog1 134 193 1967.35 1976.25 328
prog1 134 196 1967.35 1976.25 329
prog1 136 138 1967.35 1976.25 330
prog1 136 142 1967.35 1976.25 331
prog1 136 144 1967.35 1976.25 332
prog1 136 146 1967.35 1976.25 333
prog1 136 156 1967.35 1976.25 334
prog1 136 158 1967.35 1976.25 335
prog1 136 172 1967.35 1976.25 336
prog1 136 174 1967.35 1976.25 337
prog1 136 178 1967.35 1976.25 338
prog1 136 182 1967.35 1976.25 339
prog1 136 184 1967.35 1976.25 340
prog1 136 193 1967.35 1976.25 341
prog1 136 196 1967.35 1976.25 342
prog1 138 142 1967.35 1976.25 343
prog1 138 144 1967.35 1976.25 344
prog1 138 146 1967.35 1976.25 345
prog1 138 156 1967.35 1976.25 346
prog1 138 158 1967.35 1976.25 347
prog1 138 172 1967.35 1976.25 348
prog1 138 174 1967.35 1976.25 349
prog1 138 178 1967.35 1976.25 350
prog1 138 182 1967.35 1976.25 351
prog1 138 184 1967.35 1976.25 352
prog1 138 193 1967.35 1976.25 353
prog1 138 196 1967.35 1976.25 354
prog1 142 144 1967.35 1976.25 355
prog1 142 146 1967.35 1976.25 356
prog1 142 156 1967.35 1976.25 357
prog1 142 158 1967.35 1976.25 358
prog1 142 172 1967.35 1976.25 359
prog1 142 174 1967.35 1976.25 360
prog1 142 178 1967.35 1976.25 361
prog1 142 182 1967.35 1976.25 362
prog1 142 184 1967.35 1976.25 363
prog1 142 193 1967.35 1976.25 364
prog1 142 196 1967.35 1976.25 365
prog1 144 146 1967.35 1976.25 366
prog1 144 156 1967.35 1976.25 367
prog1 144 158 1967.35 1976.25 368
prog1 144 172 1967.35 1976.25 369
prog1 144 174 1967.35 1976.25 370
prog1 144 178 1967.35 1976.25 371
prog1 144 182 1967.35 1976.25 372
prog1 144 184 1967.35 1976.25 373
prog1 144 193 1967.35 1976.25 374
prog1 144 196 1967.35 1976.25 375
prog1 146 156 1967.35 1976.25 376
prog1 146 158 1967.35 1976.25 377
prog1 146 172 1967.35 1976.25 378
prog1 146 174 1967.35 1976.25 379
prog1 146 178 1967.35 1976.25 380
prog1 146 182 1967.35 1976.25 381
prog1 146 184 1967.35 1976.25 382
prog1 146 193 1967.35 1976.25 383
prog1 146 196 1967.35 1976.25 384
prog1 156 158 1967.35 1976.25 385
prog1 156 172 1967.35 1976.25 386
prog1 156 174 1967.35 1976.25 387
prog1 156 178 1967.35 1976.25 388
prog1 156 182 1967.35 1976.25 389
prog1 156 184 1967.35 1976.25 390
prog1 156 193 1967.35 1976.25 391
prog1 156 196 1967.35 1976.25 392
prog1 158 172 1967.35 1976.25 393
prog1 158 174 1967.35 1976.25 394
prog1 158 178 1967.35 1976.25 395
prog1 158 182 1967.35 1976.25 396
prog1 158 184 1967.35 1976.25 397
prog1 158 193 1967.35 1976.25 398
prog1 158 196 1967.35 1976.25 399
prog1 172 174 1967.35 1976.25 400
prog1 172 178 1967.35 1976.25 401
prog1 172 182 1967.35 1976.25 402
prog1 172 184 1967.35 1976.25 403
prog1 172 193 1967.35 1976.25 404
prog1 172 196 1967.35 1976.25 405
prog1 174 178 1967.35 1976.25 406
prog1 174 182 1967.35 1976.25 407
prog1 174 184 1967.35 1976.25 408
prog1 174 193 1967.35 1976.25 409
prog1 174 196 1967.35 1976.25 410
prog1 178 182 1967.35 1976.25 411
prog1 178 184 1967.35 1976.25 412
prog1 178 193 1967.35 1976.25 413
prog1 178 196 1967.35 1976.25 414
prog1 182 184 1967.35 1976.25 415
prog1 182 193 1967.35 1976.25 416
prog1 182 196 1967.35 1976.25 417
prog1 184 193 1967.35 1976.25 418
prog1 184 196 1967.35 1976.25 419
prog1 193 196 1967.35 1976.25 420

prog1 111 112 1976.25 1985.15 421
prog1 111 122 1976.25 1985.15 422
prog1 111 124 1976.25 1985.15 423
prog1 111 128 1976.25 1985.15 424
prog1 111 132 1976.25 1985.15 425
prog1 111 134 1976.25 1985.15 426
prog1 111 136 1976.25 1985.15 427
prog1 111 138 1976.25 1985.15 428
prog1 111 142 1976.25 1985.15 429
prog1 111 144 1976.25 1985.15 430
prog1 111 146 1976.25 1985.15 431
prog1 111 156 1976.25 1985.15 432
prog1 111 158 1976.25 1985.15 433
prog1 111 172 1976.25 1985.15 434
prog1 111 174 1976.25 1985.15 435
prog1 111 178 1976.25 1985.15 436
prog1 111 182 1976.25 1985.15 437
prog1 111 184 1976.25 1985.15 438
prog1 111 193 1976.25 1985.15 439
prog1 111 196 1976.25 1985.15 440
prog1 112 122 1976.25 1985.15 441
prog1 112 124 1976.25 1985.15 442
prog1 112 128 1976.25 1985.15 443
prog1 112 132 1976.25 1985.15 444
prog1 112 134 1976.25 1985.15 445
prog1 112 136 1976.25 1985.15 446
prog1 112 138 1976.25 1985.15 447
prog1 112 142 1976.25 1985.15 448
prog1 112 144 1976.25 1985.15 449
prog1 112 146 1976.25 1985.15 450
prog1 112 156 1976.25 1985.15 451
prog1 112 158 1976.25 1985.15 452
prog1 112 172 1976.25 1985.15 453
prog1 112 174 1976.25 1985.15 454
prog1 112 178 1976.25 1985.15 455
prog1 112 182 1976.25 1985.15 456
prog1 112 184 1976.25 1985.15 457
prog1 112 193 1976.25 1985.15 458
prog1 112 196 1976.25 1985.15 459
prog1 122 124 1976.25 1985.15 460
prog1 122 128 1976.25 1985.15 461
prog1 122 132 1976.25 1985.15 462
prog1 122 134 1976.25 1985.15 463
prog1 122 136 1976.25 1985.15 464
prog1 122 138 1976.25 1985.15 465
prog1 122 142 1976.25 1985.15 466
prog1 122 144 1976.25 1985.15 467
prog1 122 146 1976.25 1985.15 468
prog1 122 156 1976.25 1985.15 469
prog1 122 158 1976.25 1985.15 470
prog1 122 172 1976.25 1985.15 471
prog1 122 174 1976.25 1985.15 472
prog1 122 178 1976.25 1985.15 473
prog1 122 182 1976.25 1985.15 474
prog1 122 184 1976.25 1985.15 475
prog1 122 193 1976.25 1985.15 476
prog1 122 196 1976.25 1985.15 477
prog1 124 128 1976.25 1985.15 478
prog1 124 132 1976.25 1985.15 479
prog1 124 134 1976.25 1985.15 480
prog1 124 136 1976.25 1985.15 481
prog1 124 138 1976.25 1985.15 482
prog1 124 142 1976.25 1985.15 483
prog1 124 144 1976.25 1985.15 484
prog1 124 146 1976.25 1985.15 485
prog1 124 156 1976.25 1985.15 486
prog1 124 158 1976.25 1985.15 487
prog1 124 172 1976.25 1985.15 488
prog1 124 174 1976.25 1985.15 489
prog1 124 178 1976.25 1985.15 490
prog1 124 182 1976.25 1985.15 491
prog1 124 184 1976.25 1985.15 492
prog1 124 193 1976.25 1985.15 493
prog1 124 196 1976.25 1985.15 494
prog1 128 132 1976.25 1985.15 495
prog1 128 134 1976.25 1985.15 496
prog1 128 136 1976.25 1985.15 497
prog1 128 138 1976.25 1985.15 498
prog1 128 142 1976.25 1985.15 499
prog1 128 144 1976.25 1985.15 500
prog1 128 146 1976.25 1985.15 501
prog1 128 156 1976.25 1985.15 502
prog1 128 158 1976.25 1985.15 503
prog1 128 172 1976.25 1985.15 504
prog1 128 174 1976.25 1985.15 505
prog1 128 178 1976.25 1985.15 506
prog1 128 182 1976.25 1985.15 507
prog1 128 184 1976.25 1985.15 508
prog1 128 193 1976.25 1985.15 509
prog1 128 196 1976.25 1985.15 510
prog1 132 134 1976.25 1985.15 511
prog1 132 136 1976.25 1985.15 512
prog1 132 138 1976.25 1985.15 513
prog1 132 142 1976.25 1985.15 514
prog1 132 144 1976.25 1985.15 515
prog1 132 146 1976.25 1985.15 516
prog1 132 156 1976.25 1985.15 517
prog1 132 158 1976.25 1985.15 518
prog1 132 172 1976.25 1985.15 519
prog1 132 174 1976.25 1985.15 520
prog1 132 178 1976.25 1985.15 521
prog1 132 182 1976.25 1985.15 522
prog1 132 184 1976.25 1985.15 523
prog1 132 193 1976.25 1985.15 524
prog1 132 196 1976.25 1985.15 525
prog1 134 136 1976.25 1985.15 526
prog1 134 138 1976.25 1985.15 527
prog1 134 142 1976.25 1985.15 528
prog1 134 144 1976.25 1985.15 529
prog1 134 146 1976.25 1985.15 530
prog1 134 156 1976.25 1985.15 531
prog1 134 158 1976.25 1985.15 532
prog1 134 172 1976.25 1985.15 533
prog1 134 174 1976.25 1985.15 534
prog1 134 178 1976.25 1985.15 535
prog1 134 182 1976.25 1985.15 536
prog1 134 184 1976.25 1985.15 537
prog1 134 193 1976.25 1985.15 538
prog1 134 196 1976.25 1985.15 539
prog1 136 138 1976.25 1985.15 540
prog1 136 142 1976.25 1985.15 541
prog1 136 144 1976.25 1985.15 542
prog1 136 146 1976.25 1985.15 543
prog1 136 156 1976.25 1985.15 544
prog1 136 158 1976.25 1985.15 545
prog1 136 172 1976.25 1985.15 546
prog1 136 174 1976.25 1985.15 547
prog1 136 178 1976.25 1985.15 548
prog1 136 182 1976.25 1985.15 549
prog1 136 184 1976.25 1985.15 550
prog1 136 193 1976.25 1985.15 551
prog1 136 196 1976.25 1985.15 552
prog1 138 142 1976.25 1985.15 553
prog1 138 144 1976.25 1985.15 554
prog1 138 146 1976.25 1985.15 555
prog1 138 156 1976.25 1985.15 556
prog1 138 158 1976.25 1985.15 557
prog1 138 172 1976.25 1985.15 558
prog1 138 174 1976.25 1985.15 559
prog1 138 178 1976.25 1985.15 560
prog1 138 182 1976.25 1985.15 561
prog1 138 184 1976.25 1985.15 562
prog1 138 193 1976.25 1985.15 563
prog1 138 196 1976.25 1985.15 564
prog1 142 144 1976.25 1985.15 565
prog1 142 146 1976.25 1985.15 566
prog1 142 156 1976.25 1985.15 567
prog1 142 158 1976.25 1985.15 568
prog1 142 172 1976.25 1985.15 569
prog1 142 174 1976.25 1985.15 570
prog1 142 178 1976.25 1985.15 571
prog1 142 182 1976.25 1985.15 572
prog1 142 184 1976.25 1985.15 573
prog1 142 193 1976.25 1985.15 574
prog1 142 196 1976.25 1985.15 575
prog1 144 146 1976.25 1985.15 576
prog1 144 156 1976.25 1985.15 577
prog1 144 158 1976.25 1985.15 578
prog1 144 172 1976.25 1985.15 579
prog1 144 174 1976.25 1985.15 580
prog1 144 178 1976.25 1985.15 581
prog1 144 182 1976.25 1985.15 582
prog1 144 184 1976.25 1985.15 583
prog1 144 193 1976.25 1985.15 584
prog1 144 196 1976.25 1985.15 585
prog1 146 156 1976.25 1985.15 586
prog1 146 158 1976.25 1985.15 587
prog1 146 172 1976.25 1985.15 588
prog1 146 174 1976.25 1985.15 589
prog1 146 178 1976.25 1985.15 590
prog1 146 182 1976.25 1985.15 591
prog1 146 184 1976.25 1985.15 592
prog1 146 193 1976.25 1985.15 593
prog1 146 196 1976.25 1985.15 594
prog1 156 158 1976.25 1985.15 595
prog1 156 172 1976.25 1985.15 596
prog1 156 174 1976.25 1985.15 597
prog1 156 178 1976.25 1985.15 598
prog1 156 182 1976.25 1985.15 599
prog1 156 184 1976.25 1985.15 600
prog1 156 193 1976.25 1985.15 601
prog1 156 196 1976.25 1985.15 602
prog1 158 172 1976.25 1985.15 603
prog1 158 174 1976.25 1985.15 604
prog1 158 178 1976.25 1985.15 605
prog1 158 182 1976.25 1985.15 606
prog1 158 184 1976.25 1985.15 607
prog1 158 193 1976.25 1985.15 608
prog1 158 196 1976.25 1985.15 609
prog1 172 174 1976.25 1985.15 610
prog1 172 178 1976.25 1985.15 611
prog1 172 182 1976.25 1985.15 612
prog1 172 184 1976.25 1985.15 613
prog1 172 193 1976.25 1985.15 614
prog1 172 196 1976.25 1985.15 615
prog1 174 178 1976.25 1985.15 616
prog1 174 182 1976.25 1985.15 617
prog1 174 184 1976.25 1985.15 618
prog1 174 193 1976.25 1985.15 619
prog1 174 196 1976.25 1985.15 620
prog1 178 182 1976.25 1985.15 621
prog1 178 184 1976.25 1985.15 622
prog1 178 193 1976.25 1985.15 623
prog1 178 196 1976.25 1985.15 624
prog1 182 184 1976.25 1985.15 625
prog1 182 193 1976.25 1985.15 626
prog1 182 196 1976.25 1985.15 627
prog1 184 193 1976.25 1985.15 628
prog1 184 196 1976.25 1985.15 629
prog1 193 196 1976.25 1985.15 630

prog1 111 112 1985.15 1995.15 631
prog1 111 122 1985.15 1995.15 632
prog1 111 124 1985.15 1995.15 633
prog1 111 128 1985.15 1995.15 634
prog1 111 132 1985.15 1995.15 635
prog1 111 134 1985.15 1995.15 636
prog1 111 136 1985.15 1995.15 637
prog1 111 138 1985.15 1995.15 638
prog1 111 142 1985.15 1995.15 639
prog1 111 144 1985.15 1995.15 640
prog1 111 146 1985.15 1995.15 641
prog1 111 156 1985.15 1995.15 642
prog1 111 158 1985.15 1995.15 643
prog1 111 172 1985.15 1995.15 644
prog1 111 174 1985.15 1995.15 645
prog1 111 178 1985.15 1995.15 646
prog1 111 182 1985.15 1995.15 647
prog1 111 184 1985.15 1995.15 648
prog1 111 193 1985.15 1995.15 649
prog1 111 196 1985.15 1995.15 650
prog1 112 122 1985.15 1995.15 651
prog1 112 124 1985.15 1995.15 652
prog1 112 128 1985.15 1995.15 653
prog1 112 132 1985.15 1995.15 654
prog1 112 134 1985.15 1995.15 655
prog1 112 136 1985.15 1995.15 656
prog1 112 138 1985.15 1995.15 657
prog1 112 142 1985.15 1995.15 658
prog1 112 144 1985.15 1995.15 659
prog1 112 146 1985.15 1995.15 660
prog1 112 156 1985.15 1995.15 661
prog1 112 158 1985.15 1995.15 662
prog1 112 172 1985.15 1995.15 663
prog1 112 174 1985.15 1995.15 664
prog1 112 178 1985.15 1995.15 665
prog1 112 182 1985.15 1995.15 666
prog1 112 184 1985.15 1995.15 667
prog1 112 193 1985.15 1995.15 668
prog1 112 196 1985.15 1995.15 669
prog1 122 124 1985.15 1995.15 670
prog1 122 128 1985.15 1995.15 671
prog1 122 132 1985.15 1995.15 672
prog1 122 134 1985.15 1995.15 673
prog1 122 136 1985.15 1995.15 674
prog1 122 138 1985.15 1995.15 675
prog1 122 142 1985.15 1995.15 676
prog1 122 144 1985.15 1995.15 677
prog1 122 146 1985.15 1995.15 678
prog1 122 156 1985.15 1995.15 679
prog1 122 158 1985.15 1995.15 680
prog1 122 172 1985.15 1995.15 681
prog1 122 174 1985.15 1995.15 682
prog1 122 178 1985.15 1995.15 683
prog1 122 182 1985.15 1995.15 684
prog1 122 184 1985.15 1995.15 685
prog1 122 193 1985.15 1995.15 686
prog1 122 196 1985.15 1995.15 687
prog1 124 128 1985.15 1995.15 688
prog1 124 132 1985.15 1995.15 689
prog1 124 134 1985.15 1995.15 690
prog1 124 136 1985.15 1995.15 691
prog1 124 138 1985.15 1995.15 692
prog1 124 142 1985.15 1995.15 693
prog1 124 144 1985.15 1995.15 694
prog1 124 146 1985.15 1995.15 695
prog1 124 156 1985.15 1995.15 696
prog1 124 158 1985.15 1995.15 697
prog1 124 172 1985.15 1995.15 698
prog1 124 174 1985.15 1995.15 699
prog1 124 178 1985.15 1995.15 700
prog1 124 182 1985.15 1995.15 701
prog1 124 184 1985.15 1995.15 702
prog1 124 193 1985.15 1995.15 703
prog1 124 196 1985.15 1995.15 704
prog1 128 132 1985.15 1995.15 705
prog1 128 134 1985.15 1995.15 706
prog1 128 136 1985.15 1995.15 707
prog1 128 138 1985.15 1995.15 708
prog1 128 142 1985.15 1995.15 709
prog1 128 144 1985.15 1995.15 710
prog1 128 146 1985.15 1995.15 711
prog1 128 156 1985.15 1995.15 712
prog1 128 158 1985.15 1995.15 713
prog1 128 172 1985.15 1995.15 714
prog1 128 174 1985.15 1995.15 715
prog1 128 178 1985.15 1995.15 716
prog1 128 182 1985.15 1995.15 717
prog1 128 184 1985.15 1995.15 718
prog1 128 193 1985.15 1995.15 719
prog1 128 196 1985.15 1995.15 720
prog1 132 134 1985.15 1995.15 721
prog1 132 136 1985.15 1995.15 722
prog1 132 138 1985.15 1995.15 723
prog1 132 142 1985.15 1995.15 724
prog1 132 144 1985.15 1995.15 725
prog1 132 146 1985.15 1995.15 726
prog1 132 156 1985.15 1995.15 727
prog1 132 158 1985.15 1995.15 728
prog1 132 172 1985.15 1995.15 729
prog1 132 174 1985.15 1995.15 730
prog1 132 178 1985.15 1995.15 731
prog1 132 182 1985.15 1995.15 732
prog1 132 184 1985.15 1995.15 733
prog1 132 193 1985.15 1995.15 734
prog1 132 196 1985.15 1995.15 735
prog1 134 136 1985.15 1995.15 736
prog1 134 138 1985.15 1995.15 737
prog1 134 142 1985.15 1995.15 738
prog1 134 144 1985.15 1995.15 739
prog1 134 146 1985.15 1995.15 740
prog1 134 156 1985.15 1995.15 741
prog1 134 158 1985.15 1995.15 742
prog1 134 172 1985.15 1995.15 743
prog1 134 174 1985.15 1995.15 744
prog1 134 178 1985.15 1995.15 745
prog1 134 182 1985.15 1995.15 746
prog1 134 184 1985.15 1995.15 747
prog1 134 193 1985.15 1995.15 748
prog1 134 196 1985.15 1995.15 749
prog1 136 138 1985.15 1995.15 750
prog1 136 142 1985.15 1995.15 751
prog1 136 144 1985.15 1995.15 752
prog1 136 146 1985.15 1995.15 753
prog1 136 156 1985.15 1995.15 754
prog1 136 158 1985.15 1995.15 755
prog1 136 172 1985.15 1995.15 756
prog1 136 174 1985.15 1995.15 757
prog1 136 178 1985.15 1995.15 758
prog1 136 182 1985.15 1995.15 759
prog1 136 184 1985.15 1995.15 760
prog1 136 193 1985.15 1995.15 761
prog1 136 196 1985.15 1995.15 762
prog1 138 142 1985.15 1995.15 763
prog1 138 144 1985.15 1995.15 764
prog1 138 146 1985.15 1995.15 765
prog1 138 156 1985.15 1995.15 766
prog1 138 158 1985.15 1995.15 767
prog1 138 172 1985.15 1995.15 768
prog1 138 174 1985.15 1995.15 769
prog1 138 178 1985.15 1995.15 770
prog1 138 182 1985.15 1995.15 771
prog1 138 184 1985.15 1995.15 772
prog1 138 193 1985.15 1995.15 773
prog1 138 196 1985.15 1995.15 774
prog1 142 144 1985.15 1995.15 775
prog1 142 146 1985.15 1995.15 776
prog1 142 156 1985.15 1995.15 777
prog1 142 158 1985.15 1995.15 778
prog1 142 172 1985.15 1995.15 779
prog1 142 174 1985.15 1995.15 780
prog1 142 178 1985.15 1995.15 781
prog1 142 182 1985.15 1995.15 782
prog1 142 184 1985.15 1995.15 783
prog1 142 193 1985.15 1995.15 784
prog1 142 196 1985.15 1995.15 785
prog1 144 146 1985.15 1995.15 786
prog1 144 156 1985.15 1995.15 787
prog1 144 158 1985.15 1995.15 788
prog1 144 172 1985.15 1995.15 789
prog1 144 174 1985.15 1995.15 790
prog1 144 178 1985.15 1995.15 791
prog1 144 182 1985.15 1995.15 792
prog1 144 184 1985.15 1995.15 793
prog1 144 193 1985.15 1995.15 794
prog1 144 196 1985.15 1995.15 795
prog1 146 156 1985.15 1995.15 796
prog1 146 158 1985.15 1995.15 797
prog1 146 172 1985.15 1995.15 798
prog1 146 174 1985.15 1995.15 799
prog1 146 178 1985.15 1995.15 800
prog1 146 182 1985.15 1995.15 801
prog1 146 184 1985.15 1995.15 802
prog1 146 193 1985.15 1995.15 803
prog1 146 196 1985.15 1995.15 804
prog1 156 158 1985.15 1995.15 805
prog1 156 172 1985.15 1995.15 806
prog1 156 174 1985.15 1995.15 807
prog1 156 178 1985.15 1995.15 808
prog1 156 182 1985.15 1995.15 809
prog1 156 184 1985.15 1995.15 810
prog1 156 193 1985.15 1995.15 811
prog1 156 196 1985.15 1995.15 812
prog1 158 172 1985.15 1995.15 813
prog1 158 174 1985.15 1995.15 814
prog1 158 178 1985.15 1995.15 815
prog1 158 182 1985.15 1995.15 816
prog1 158 184 1985.15 1995.15 817
prog1 158 193 1985.15 1995.15 818
prog1 158 196 1985.15 1995.15 819
prog1 172 174 1985.15 1995.15 820
prog1 172 178 1985.15 1995.15 821
prog1 172 182 1985.15 1995.15 822
prog1 172 184 1985.15 1995.15 823
prog1 172 193 1985.15 1995.15 824
prog1 172 196 1985.15 1995.15 825
prog1 174 178 1985.15 1995.15 826
prog1 174 182 1985.15 1995.15 827
prog1 174 184 1985.15 1995.15 828
prog1 174 193 1985.15 1995.15 829
prog1 174 196 1985.15 1995.15 830
prog1 178 182 1985.15 1995.15 831
prog1 178 184 1985.15 1995.15 832
prog1 178 193 1985.15 1995.15 833
prog1 178 196 1985.15 1995.15 834
prog1 182 184 1985.15 1995.15 835
prog1 182 193 1985.15 1995.15 836
prog1 182 196 1985.15 1995.15 837
prog1 184 193 1985.15 1995.15 838
prog1 184 196 1985.15 1995.15 839
prog1 193 196 1985.15 1995.15 840
*
* Write out the data (and a few auxiliaries)
*
g period=1 in 1/210
replace period=2 in 211/420
replace period=3 in 421/630
replace period=4 in 631/840

compress
sort count1 count2 period
outfile period count1 count2 wx wm wt in 1/840 using \res\oca\data\weights,replace dictionary
program drop _all
drop _all
*
* Now work on the bilateral real income correlations
*
* Clean up the data set a little
*
use \res\oca\data\datav2a

g dss=oildep*((realoilp-realoilp[_n-1])/realoilp[_n-1]) if ifscode==ifscode[_n-1]
rename sshock ss

g datee=date10
drop if ifscode==199
drop if ifscode==186
drop if ifscode==181
drop if ifscode==176
drop impfrau-govstr
drop lifs99 lifs66 let
rename ifscode ifs
compress

rename dlifs99 dl99
rename dlifs66 dl66
rename tlifs99 tl99
rename hlifs99 hl99
rename slifs99 sl99
rename tlifs66 tl66
rename hlifs66 hl66
rename slifs66 sl66
rename olifs99 ol99
rename olifs66 ol66

sort ifs date10
*
* Reshape the data set from long into wide format
*
reshape cons date10
reshape vars dl99 tl99 hl99 sl99 ol99 dl66 tl66 hl66 sl66 ol66 dlet tlet hlet slet olet dunr tunr hunr sunr ounr ss dss
reshape groups ifs 111 112 122 124 128 132 134 136 138 142 144 146 156 158 172 174 178 182 184 193 196
reshape wide

set obs 840
g date=date10/10.
save \res\oca\data\crap,replace
*
* Create the empty correlations
*
g dy=. in 1/840
g di=. in 1/840
g de=. in 1/840
g du=. in 1/840
g ty=. in 1/840
g ti=. in 1/840
g te=. in 1/840
g tu=. in 1/840
g hy=. in 1/840
g hi=. in 1/840
g he=. in 1/840
g hu=. in 1/840
g sy=. in 1/840
g si=. in 1/840
g se=. in 1/840
g su=. in 1/840
g oy=. in 1/840
g oi=. in 1/840
g oe=. in 1/840
g ou=. in 1/840
g oilpxmy=.
g doilpxmy=.

label var dy "Bilateral Output Correlation, Differenced Data"
label var di "Bilateral IP Correlation, Differenced Data"
label var de "Bilateral Empl'y Correlation, Differenced Data"
label var du "Bilateral Unem't Correlation, Differenced Data"
label var ty "Bilateral Output Correlation, De-Trended Data"
label var ti "Bilateral IP Correlation, De-Trended Data"
label var te "Bilateral Empl'y Correlation, De-Trended Data"
label var tu "Bilateral Unem't Correlation, De-Trended Data"
label var hy "Bilateral Output Correlation, HP-Filtered Data"
label var hi "Bilateral IP Correlation, HP-Filtered Data"
label var he "Bilateral Empl'y Correlation, HP-Filtered Data"
label var hu "Bilateral Unem't Correlation, HP-Filtered Data"
label var sy "Bilateral Output Correlation, HP-SA Data"
label var si "Bilateral IP Correlation, HP-SA Data"
label var se "Bilateral Empl'y Correlation, HP-SA Data"
label var su "Bilateral Unem't Correlation, HP-SA Data"
label var oy "Bilateral Output Correlation, Oil De-Trended Data"
label var oi "Bilateral IP Correlation, Oil De-Trended Data"
label var oe "Bilateral Empl'y Correlation, Oil De-Trended Data"
label var ou "Bilateral Unem't Correlation, Oil De-Trended Data"
label var oilpxmy "Oil Price/World CPI*(BoT in Oil/GNP)
label var doilpxmy "d Oil Price/World CPI*(BoT in Oil/GNP)

g count1=. in 1/840
g count2=. in 1/840

label var count1 "Exporter or Importer"
label var count2 "Exportee or Import Sender"
*
* A program to compute correlations and also the supply shocks
*
program define prog2 /* country1 country2 start end obs*/
	quietly replace count1=`1' in `5'/`5'
	quietly replace count2=`2' in `5'/`5'
	quietly corr dl99`1' dl99`2' if date>`3'&date<`4'
	quietly replace dy=_result(4) in `5'
	quietly corr dl66`1' dl66`2' if date>`3'&date<`4'
	quietly replace di=_result(4) in `5'
	quietly corr dlet`1' dlet`2' if date>`3'&date<`4'
	quietly replace de=_result(4) in `5'
	quietly corr dunr`1' dunr`2' if date>`3'&date<`4'
	quietly replace du=_result(4) in `5'
	quietly corr tl99`1' tl99`2' if date>`3'&date<`4'
	quietly replace ty=_result(4) in `5'
	quietly corr tl66`1' tl66`2' if date>`3'&date<`4'
	quietly replace ti=_result(4) in `5'
	quietly corr tlet`1' tlet`2' if date>`3'&date<`4'
	quietly replace te=_result(4) in `5'
	quietly corr tunr`1' tunr`2' if date>`3'&date<`4'
	quietly replace tu=_result(4) in `5'
	quietly corr hl99`1' hl99`2' if date>`3'&date<`4'
	quietly replace hy=_result(4) in `5'
	quietly corr hl66`1' hl66`2' if date>`3'&date<`4'
	quietly replace hi=_result(4) in `5'
	quietly corr hlet`1' hlet`2' if date>`3'&date<`4'
	quietly replace he=_result(4) in `5'
	quietly corr hunr`1' hunr`2' if date>`3'&date<`4'
	quietly replace hu=_result(4) in `5'
	quietly corr sl99`1' sl99`2' if date>`3'&date<`4'
	quietly replace sy=_result(4) in `5'
	quietly corr sl66`1' sl66`2' if date>`3'&date<`4'
	quietly replace si=_result(4) in `5'
	quietly corr slet`1' slet`2' if date>`3'&date<`4'
	quietly replace se=_result(4) in `5'
	quietly corr sunr`1' sunr`2' if date>`3'&date<`4'
	quietly replace su=_result(4) in `5'
	quietly corr ol99`1' ol99`2' if date>`3'&date<`4'
	quietly replace oy=_result(4) in `5'
	quietly corr ol66`1' ol66`2' if date>`3'&date<`4'
	quietly replace oi=_result(4) in `5'
	quietly corr olet`1' olet`2' if date>`3'&date<`4'
	quietly replace oe=_result(4) in `5'
	quietly corr ounr`1' ounr`2' if date>`3'&date<`4'
	quietly replace ou=_result(4) in `5'
	quietly g crap=ss`1'*ss`2' if date>`3'&date<`4'
	quietly sum crap if date>`3'&date<`4'
	quietly replace oilpxmy=_result(3) in `5'
	quietly drop crap
	quietly g crapd=dss`1'*dss`2' if date>`3'&date<`4'
	quietly sum crapd if date>`3'&date<`4'
	quietly replace doilpxmy=_result(3) in `5'
	quietly drop crapd
	end
*
* Compute the weights
*
prog2 111 112 1950.05 1967.35 1
prog2 111 122 1950.05 1967.35 2
prog2 111 124 1950.05 1967.35 3
prog2 111 128 1950.05 1967.35 4
prog2 111 132 1950.05 1967.35 5
prog2 111 134 1950.05 1967.35 6
prog2 111 136 1950.05 1967.35 7
prog2 111 138 1950.05 1967.35 8
prog2 111 142 1950.05 1967.35 9
prog2 111 144 1950.05 1967.35 10
prog2 111 146 1950.05 1967.35 11
prog2 111 156 1950.05 1967.35 12
prog2 111 158 1950.05 1967.35 13
prog2 111 172 1950.05 1967.35 14
prog2 111 174 1950.05 1967.35 15
prog2 111 178 1950.05 1967.35 16
prog2 111 182 1950.05 1967.35 17
prog2 111 184 1950.05 1967.35 18
prog2 111 193 1950.05 1967.35 19
prog2 111 196 1950.05 1967.35 20
prog2 112 122 1950.05 1967.35 21
prog2 112 124 1950.05 1967.35 22
prog2 112 128 1950.05 1967.35 23
prog2 112 132 1950.05 1967.35 24
prog2 112 134 1950.05 1967.35 25
prog2 112 136 1950.05 1967.35 26
prog2 112 138 1950.05 1967.35 27
prog2 112 142 1950.05 1967.35 28
prog2 112 144 1950.05 1967.35 29
prog2 112 146 1950.05 1967.35 30
prog2 112 156 1950.05 1967.35 31
prog2 112 158 1950.05 1967.35 32
prog2 112 172 1950.05 1967.35 33
prog2 112 174 1950.05 1967.35 34
prog2 112 178 1950.05 1967.35 35
prog2 112 182 1950.05 1967.35 36
prog2 112 184 1950.05 1967.35 37
prog2 112 193 1950.05 1967.35 38
prog2 112 196 1950.05 1967.35 39
prog2 122 124 1950.05 1967.35 40
prog2 122 128 1950.05 1967.35 41
prog2 122 132 1950.05 1967.35 42
prog2 122 134 1950.05 1967.35 43
prog2 122 136 1950.05 1967.35 44
prog2 122 138 1950.05 1967.35 45
prog2 122 142 1950.05 1967.35 46
prog2 122 144 1950.05 1967.35 47
prog2 122 146 1950.05 1967.35 48
prog2 122 156 1950.05 1967.35 49
prog2 122 158 1950.05 1967.35 50
prog2 122 172 1950.05 1967.35 51
prog2 122 174 1950.05 1967.35 52
prog2 122 178 1950.05 1967.35 53
prog2 122 182 1950.05 1967.35 54
prog2 122 184 1950.05 1967.35 55
prog2 122 193 1950.05 1967.35 56
prog2 122 196 1950.05 1967.35 57
prog2 124 128 1950.05 1967.35 58
prog2 124 132 1950.05 1967.35 59
prog2 124 134 1950.05 1967.35 60
prog2 124 136 1950.05 1967.35 61
prog2 124 138 1950.05 1967.35 62
prog2 124 142 1950.05 1967.35 63
prog2 124 144 1950.05 1967.35 64
prog2 124 146 1950.05 1967.35 65
prog2 124 156 1950.05 1967.35 66
prog2 124 158 1950.05 1967.35 67
prog2 124 172 1950.05 1967.35 68
prog2 124 174 1950.05 1967.35 69
prog2 124 178 1950.05 1967.35 70
prog2 124 182 1950.05 1967.35 71
prog2 124 184 1950.05 1967.35 72
prog2 124 193 1950.05 1967.35 73
prog2 124 196 1950.05 1967.35 74
prog2 128 132 1950.05 1967.35 75
prog2 128 134 1950.05 1967.35 76
prog2 128 136 1950.05 1967.35 77
prog2 128 138 1950.05 1967.35 78
prog2 128 142 1950.05 1967.35 79
prog2 128 144 1950.05 1967.35 80
prog2 128 146 1950.05 1967.35 81
prog2 128 156 1950.05 1967.35 82
prog2 128 158 1950.05 1967.35 83
prog2 128 172 1950.05 1967.35 84
prog2 128 174 1950.05 1967.35 85
prog2 128 178 1950.05 1967.35 86
prog2 128 182 1950.05 1967.35 87
prog2 128 184 1950.05 1967.35 88
prog2 128 193 1950.05 1967.35 89
prog2 128 196 1950.05 1967.35 90
prog2 132 134 1950.05 1967.35 91
prog2 132 136 1950.05 1967.35 92
prog2 132 138 1950.05 1967.35 93
prog2 132 142 1950.05 1967.35 94
prog2 132 144 1950.05 1967.35 95
prog2 132 146 1950.05 1967.35 96
prog2 132 156 1950.05 1967.35 97
prog2 132 158 1950.05 1967.35 98
prog2 132 172 1950.05 1967.35 99
prog2 132 174 1950.05 1967.35 100
prog2 132 178 1950.05 1967.35 101
prog2 132 182 1950.05 1967.35 102
prog2 132 184 1950.05 1967.35 103
prog2 132 193 1950.05 1967.35 104
prog2 132 196 1950.05 1967.35 105
prog2 134 136 1950.05 1967.35 106
prog2 134 138 1950.05 1967.35 107
prog2 134 142 1950.05 1967.35 108
prog2 134 144 1950.05 1967.35 109
prog2 134 146 1950.05 1967.35 110
prog2 134 156 1950.05 1967.35 111
prog2 134 158 1950.05 1967.35 112
prog2 134 172 1950.05 1967.35 113
prog2 134 174 1950.05 1967.35 114
prog2 134 178 1950.05 1967.35 115
prog2 134 182 1950.05 1967.35 116
prog2 134 184 1950.05 1967.35 117
prog2 134 193 1950.05 1967.35 118
prog2 134 196 1950.05 1967.35 119
prog2 136 138 1950.05 1967.35 120
prog2 136 142 1950.05 1967.35 121
prog2 136 144 1950.05 1967.35 122
prog2 136 146 1950.05 1967.35 123
prog2 136 156 1950.05 1967.35 124
prog2 136 158 1950.05 1967.35 125
prog2 136 172 1950.05 1967.35 126
prog2 136 174 1950.05 1967.35 127
prog2 136 178 1950.05 1967.35 128
prog2 136 182 1950.05 1967.35 129
prog2 136 184 1950.05 1967.35 130
prog2 136 193 1950.05 1967.35 131
prog2 136 196 1950.05 1967.35 132
prog2 138 142 1950.05 1967.35 133
prog2 138 144 1950.05 1967.35 134
prog2 138 146 1950.05 1967.35 135
prog2 138 156 1950.05 1967.35 136
prog2 138 158 1950.05 1967.35 137
prog2 138 172 1950.05 1967.35 138
prog2 138 174 1950.05 1967.35 139
prog2 138 178 1950.05 1967.35 140
prog2 138 182 1950.05 1967.35 141
prog2 138 184 1950.05 1967.35 142
prog2 138 193 1950.05 1967.35 143
prog2 138 196 1950.05 1967.35 144
prog2 142 144 1950.05 1967.35 145
prog2 142 146 1950.05 1967.35 146
prog2 142 156 1950.05 1967.35 147
prog2 142 158 1950.05 1967.35 148
prog2 142 172 1950.05 1967.35 149
prog2 142 174 1950.05 1967.35 150
prog2 142 178 1950.05 1967.35 151
prog2 142 182 1950.05 1967.35 152
prog2 142 184 1950.05 1967.35 153
prog2 142 193 1950.05 1967.35 154
prog2 142 196 1950.05 1967.35 155
prog2 144 146 1950.05 1967.35 156
prog2 144 156 1950.05 1967.35 157
prog2 144 158 1950.05 1967.35 158
prog2 144 172 1950.05 1967.35 159
prog2 144 174 1950.05 1967.35 160
prog2 144 178 1950.05 1967.35 161
prog2 144 182 1950.05 1967.35 162
prog2 144 184 1950.05 1967.35 163
prog2 144 193 1950.05 1967.35 164
prog2 144 196 1950.05 1967.35 165
prog2 146 156 1950.05 1967.35 166
prog2 146 158 1950.05 1967.35 167
prog2 146 172 1950.05 1967.35 168
prog2 146 174 1950.05 1967.35 169
prog2 146 178 1950.05 1967.35 170
prog2 146 182 1950.05 1967.35 171
prog2 146 184 1950.05 1967.35 172
prog2 146 193 1950.05 1967.35 173
prog2 146 196 1950.05 1967.35 174
prog2 156 158 1950.05 1967.35 175
prog2 156 172 1950.05 1967.35 176
prog2 156 174 1950.05 1967.35 177
prog2 156 178 1950.05 1967.35 178
prog2 156 182 1950.05 1967.35 179
prog2 156 184 1950.05 1967.35 180
prog2 156 193 1950.05 1967.35 181
prog2 156 196 1950.05 1967.35 182
prog2 158 172 1950.05 1967.35 183
prog2 158 174 1950.05 1967.35 184
prog2 158 178 1950.05 1967.35 185
prog2 158 182 1950.05 1967.35 186
prog2 158 184 1950.05 1967.35 187
prog2 158 193 1950.05 1967.35 188
prog2 158 196 1950.05 1967.35 189
prog2 172 174 1950.05 1967.35 190
prog2 172 178 1950.05 1967.35 191
prog2 172 182 1950.05 1967.35 192
prog2 172 184 1950.05 1967.35 193
prog2 172 193 1950.05 1967.35 194
prog2 172 196 1950.05 1967.35 195
prog2 174 178 1950.05 1967.35 196
prog2 174 182 1950.05 1967.35 197
prog2 174 184 1950.05 1967.35 198
prog2 174 193 1950.05 1967.35 199
prog2 174 196 1950.05 1967.35 200
prog2 178 182 1950.05 1967.35 201
prog2 178 184 1950.05 1967.35 202
prog2 178 193 1950.05 1967.35 203
prog2 178 196 1950.05 1967.35 204
prog2 182 184 1950.05 1967.35 205
prog2 182 193 1950.05 1967.35 206
prog2 182 196 1950.05 1967.35 207
prog2 184 193 1950.05 1967.35 208
prog2 184 196 1950.05 1967.35 209
prog2 193 196 1950.05 1967.35 210

prog2 111 112 1967.35 1976.25 211
prog2 111 122 1967.35 1976.25 212
prog2 111 124 1967.35 1976.25 213
prog2 111 128 1967.35 1976.25 214
prog2 111 132 1967.35 1976.25 215
prog2 111 134 1967.35 1976.25 216
prog2 111 136 1967.35 1976.25 217
prog2 111 138 1967.35 1976.25 218
prog2 111 142 1967.35 1976.25 219
prog2 111 144 1967.35 1976.25 220
prog2 111 146 1967.35 1976.25 221
prog2 111 156 1967.35 1976.25 222
prog2 111 158 1967.35 1976.25 223
prog2 111 172 1967.35 1976.25 224
prog2 111 174 1967.35 1976.25 225
prog2 111 178 1967.35 1976.25 226
prog2 111 182 1967.35 1976.25 227
prog2 111 184 1967.35 1976.25 228
prog2 111 193 1967.35 1976.25 229
prog2 111 196 1967.35 1976.25 230
prog2 112 122 1967.35 1976.25 231
prog2 112 124 1967.35 1976.25 232
prog2 112 128 1967.35 1976.25 233
prog2 112 132 1967.35 1976.25 234
prog2 112 134 1967.35 1976.25 235
prog2 112 136 1967.35 1976.25 236
prog2 112 138 1967.35 1976.25 237
prog2 112 142 1967.35 1976.25 238
prog2 112 144 1967.35 1976.25 239
prog2 112 146 1967.35 1976.25 240
prog2 112 156 1967.35 1976.25 241
prog2 112 158 1967.35 1976.25 242
prog2 112 172 1967.35 1976.25 243
prog2 112 174 1967.35 1976.25 244
prog2 112 178 1967.35 1976.25 245
prog2 112 182 1967.35 1976.25 246
prog2 112 184 1967.35 1976.25 247
prog2 112 193 1967.35 1976.25 248
prog2 112 196 1967.35 1976.25 249
prog2 122 124 1967.35 1976.25 250
prog2 122 128 1967.35 1976.25 251
prog2 122 132 1967.35 1976.25 252
prog2 122 134 1967.35 1976.25 253
prog2 122 136 1967.35 1976.25 254
prog2 122 138 1967.35 1976.25 255
prog2 122 142 1967.35 1976.25 256
prog2 122 144 1967.35 1976.25 257
prog2 122 146 1967.35 1976.25 258
prog2 122 156 1967.35 1976.25 259
prog2 122 158 1967.35 1976.25 260
prog2 122 172 1967.35 1976.25 261
prog2 122 174 1967.35 1976.25 262
prog2 122 178 1967.35 1976.25 263
prog2 122 182 1967.35 1976.25 264
prog2 122 184 1967.35 1976.25 265
prog2 122 193 1967.35 1976.25 266
prog2 122 196 1967.35 1976.25 267
prog2 124 128 1967.35 1976.25 268
prog2 124 132 1967.35 1976.25 269
prog2 124 134 1967.35 1976.25 270
prog2 124 136 1967.35 1976.25 271
prog2 124 138 1967.35 1976.25 272
prog2 124 142 1967.35 1976.25 273
prog2 124 144 1967.35 1976.25 274
prog2 124 146 1967.35 1976.25 275
prog2 124 156 1967.35 1976.25 276
prog2 124 158 1967.35 1976.25 277
prog2 124 172 1967.35 1976.25 278
prog2 124 174 1967.35 1976.25 279
prog2 124 178 1967.35 1976.25 280
prog2 124 182 1967.35 1976.25 281
prog2 124 184 1967.35 1976.25 282
prog2 124 193 1967.35 1976.25 283
prog2 124 196 1967.35 1976.25 284
prog2 128 132 1967.35 1976.25 285
prog2 128 134 1967.35 1976.25 286
prog2 128 136 1967.35 1976.25 287
prog2 128 138 1967.35 1976.25 288
prog2 128 142 1967.35 1976.25 289
prog2 128 144 1967.35 1976.25 290
prog2 128 146 1967.35 1976.25 291
prog2 128 156 1967.35 1976.25 292
prog2 128 158 1967.35 1976.25 293
prog2 128 172 1967.35 1976.25 294
prog2 128 174 1967.35 1976.25 295
prog2 128 178 1967.35 1976.25 296
prog2 128 182 1967.35 1976.25 297
prog2 128 184 1967.35 1976.25 298
prog2 128 193 1967.35 1976.25 299
prog2 128 196 1967.35 1976.25 300
prog2 132 134 1967.35 1976.25 301
prog2 132 136 1967.35 1976.25 302
prog2 132 138 1967.35 1976.25 303
prog2 132 142 1967.35 1976.25 304
prog2 132 144 1967.35 1976.25 305
prog2 132 146 1967.35 1976.25 306
prog2 132 156 1967.35 1976.25 307
prog2 132 158 1967.35 1976.25 308
prog2 132 172 1967.35 1976.25 309
prog2 132 174 1967.35 1976.25 310
prog2 132 178 1967.35 1976.25 311
prog2 132 182 1967.35 1976.25 312
prog2 132 184 1967.35 1976.25 313
prog2 132 193 1967.35 1976.25 314
prog2 132 196 1967.35 1976.25 315
prog2 134 136 1967.35 1976.25 316
prog2 134 138 1967.35 1976.25 317
prog2 134 142 1967.35 1976.25 318
prog2 134 144 1967.35 1976.25 319
prog2 134 146 1967.35 1976.25 320
prog2 134 156 1967.35 1976.25 321
prog2 134 158 1967.35 1976.25 322
prog2 134 172 1967.35 1976.25 323
prog2 134 174 1967.35 1976.25 324
prog2 134 178 1967.35 1976.25 325
prog2 134 182 1967.35 1976.25 326
prog2 134 184 1967.35 1976.25 327
prog2 134 193 1967.35 1976.25 328
prog2 134 196 1967.35 1976.25 329
prog2 136 138 1967.35 1976.25 330
prog2 136 142 1967.35 1976.25 331
prog2 136 144 1967.35 1976.25 332
prog2 136 146 1967.35 1976.25 333
prog2 136 156 1967.35 1976.25 334
prog2 136 158 1967.35 1976.25 335
prog2 136 172 1967.35 1976.25 336
prog2 136 174 1967.35 1976.25 337
prog2 136 178 1967.35 1976.25 338
prog2 136 182 1967.35 1976.25 339
prog2 136 184 1967.35 1976.25 340
prog2 136 193 1967.35 1976.25 341
prog2 136 196 1967.35 1976.25 342
prog2 138 142 1967.35 1976.25 343
prog2 138 144 1967.35 1976.25 344
prog2 138 146 1967.35 1976.25 345
prog2 138 156 1967.35 1976.25 346
prog2 138 158 1967.35 1976.25 347
prog2 138 172 1967.35 1976.25 348
prog2 138 174 1967.35 1976.25 349
prog2 138 178 1967.35 1976.25 350
prog2 138 182 1967.35 1976.25 351
prog2 138 184 1967.35 1976.25 352
prog2 138 193 1967.35 1976.25 353
prog2 138 196 1967.35 1976.25 354
prog2 142 144 1967.35 1976.25 355
prog2 142 146 1967.35 1976.25 356
prog2 142 156 1967.35 1976.25 357
prog2 142 158 1967.35 1976.25 358
prog2 142 172 1967.35 1976.25 359
prog2 142 174 1967.35 1976.25 360
prog2 142 178 1967.35 1976.25 361
prog2 142 182 1967.35 1976.25 362
prog2 142 184 1967.35 1976.25 363
prog2 142 193 1967.35 1976.25 364
prog2 142 196 1967.35 1976.25 365
prog2 144 146 1967.35 1976.25 366
prog2 144 156 1967.35 1976.25 367
prog2 144 158 1967.35 1976.25 368
prog2 144 172 1967.35 1976.25 369
prog2 144 174 1967.35 1976.25 370
prog2 144 178 1967.35 1976.25 371
prog2 144 182 1967.35 1976.25 372
prog2 144 184 1967.35 1976.25 373
prog2 144 193 1967.35 1976.25 374
prog2 144 196 1967.35 1976.25 375
prog2 146 156 1967.35 1976.25 376
prog2 146 158 1967.35 1976.25 377
prog2 146 172 1967.35 1976.25 378
prog2 146 174 1967.35 1976.25 379
prog2 146 178 1967.35 1976.25 380
prog2 146 182 1967.35 1976.25 381
prog2 146 184 1967.35 1976.25 382
prog2 146 193 1967.35 1976.25 383
prog2 146 196 1967.35 1976.25 384
prog2 156 158 1967.35 1976.25 385
prog2 156 172 1967.35 1976.25 386
prog2 156 174 1967.35 1976.25 387
prog2 156 178 1967.35 1976.25 388
prog2 156 182 1967.35 1976.25 389
prog2 156 184 1967.35 1976.25 390
prog2 156 193 1967.35 1976.25 391
prog2 156 196 1967.35 1976.25 392
prog2 158 172 1967.35 1976.25 393
prog2 158 174 1967.35 1976.25 394
prog2 158 178 1967.35 1976.25 395
prog2 158 182 1967.35 1976.25 396
prog2 158 184 1967.35 1976.25 397
prog2 158 193 1967.35 1976.25 398
prog2 158 196 1967.35 1976.25 399
prog2 172 174 1967.35 1976.25 400
prog2 172 178 1967.35 1976.25 401
prog2 172 182 1967.35 1976.25 402
prog2 172 184 1967.35 1976.25 403
prog2 172 193 1967.35 1976.25 404
prog2 172 196 1967.35 1976.25 405
prog2 174 178 1967.35 1976.25 406
prog2 174 182 1967.35 1976.25 407
prog2 174 184 1967.35 1976.25 408
prog2 174 193 1967.35 1976.25 409
prog2 174 196 1967.35 1976.25 410
prog2 178 182 1967.35 1976.25 411
prog2 178 184 1967.35 1976.25 412
prog2 178 193 1967.35 1976.25 413
prog2 178 196 1967.35 1976.25 414
prog2 182 184 1967.35 1976.25 415
prog2 182 193 1967.35 1976.25 416
prog2 182 196 1967.35 1976.25 417
prog2 184 193 1967.35 1976.25 418
prog2 184 196 1967.35 1976.25 419
prog2 193 196 1967.35 1976.25 420

prog2 111 112 1976.25 1985.15 421
prog2 111 122 1976.25 1985.15 422
prog2 111 124 1976.25 1985.15 423
prog2 111 128 1976.25 1985.15 424
prog2 111 132 1976.25 1985.15 425
prog2 111 134 1976.25 1985.15 426
prog2 111 136 1976.25 1985.15 427
prog2 111 138 1976.25 1985.15 428
prog2 111 142 1976.25 1985.15 429
prog2 111 144 1976.25 1985.15 430
prog2 111 146 1976.25 1985.15 431
prog2 111 156 1976.25 1985.15 432
prog2 111 158 1976.25 1985.15 433
prog2 111 172 1976.25 1985.15 434
prog2 111 174 1976.25 1985.15 435
prog2 111 178 1976.25 1985.15 436
prog2 111 182 1976.25 1985.15 437
prog2 111 184 1976.25 1985.15 438
prog2 111 193 1976.25 1985.15 439
prog2 111 196 1976.25 1985.15 440
prog2 112 122 1976.25 1985.15 441
prog2 112 124 1976.25 1985.15 442
prog2 112 128 1976.25 1985.15 443
prog2 112 132 1976.25 1985.15 444
prog2 112 134 1976.25 1985.15 445
prog2 112 136 1976.25 1985.15 446
prog2 112 138 1976.25 1985.15 447
prog2 112 142 1976.25 1985.15 448
prog2 112 144 1976.25 1985.15 449
prog2 112 146 1976.25 1985.15 450
prog2 112 156 1976.25 1985.15 451
prog2 112 158 1976.25 1985.15 452
prog2 112 172 1976.25 1985.15 453
prog2 112 174 1976.25 1985.15 454
prog2 112 178 1976.25 1985.15 455
prog2 112 182 1976.25 1985.15 456
prog2 112 184 1976.25 1985.15 457
prog2 112 193 1976.25 1985.15 458
prog2 112 196 1976.25 1985.15 459
prog2 122 124 1976.25 1985.15 460
prog2 122 128 1976.25 1985.15 461
prog2 122 132 1976.25 1985.15 462
prog2 122 134 1976.25 1985.15 463
prog2 122 136 1976.25 1985.15 464
prog2 122 138 1976.25 1985.15 465
prog2 122 142 1976.25 1985.15 466
prog2 122 144 1976.25 1985.15 467
prog2 122 146 1976.25 1985.15 468
prog2 122 156 1976.25 1985.15 469
prog2 122 158 1976.25 1985.15 470
prog2 122 172 1976.25 1985.15 471
prog2 122 174 1976.25 1985.15 472
prog2 122 178 1976.25 1985.15 473
prog2 122 182 1976.25 1985.15 474
prog2 122 184 1976.25 1985.15 475
prog2 122 193 1976.25 1985.15 476
prog2 122 196 1976.25 1985.15 477
prog2 124 128 1976.25 1985.15 478
prog2 124 132 1976.25 1985.15 479
prog2 124 134 1976.25 1985.15 480
prog2 124 136 1976.25 1985.15 481
prog2 124 138 1976.25 1985.15 482
prog2 124 142 1976.25 1985.15 483
prog2 124 144 1976.25 1985.15 484
prog2 124 146 1976.25 1985.15 485
prog2 124 156 1976.25 1985.15 486
prog2 124 158 1976.25 1985.15 487
prog2 124 172 1976.25 1985.15 488
prog2 124 174 1976.25 1985.15 489
prog2 124 178 1976.25 1985.15 490
prog2 124 182 1976.25 1985.15 491
prog2 124 184 1976.25 1985.15 492
prog2 124 193 1976.25 1985.15 493
prog2 124 196 1976.25 1985.15 494
prog2 128 132 1976.25 1985.15 495
prog2 128 134 1976.25 1985.15 496
prog2 128 136 1976.25 1985.15 497
prog2 128 138 1976.25 1985.15 498
prog2 128 142 1976.25 1985.15 499
prog2 128 144 1976.25 1985.15 500
prog2 128 146 1976.25 1985.15 501
prog2 128 156 1976.25 1985.15 502
prog2 128 158 1976.25 1985.15 503
prog2 128 172 1976.25 1985.15 504
prog2 128 174 1976.25 1985.15 505
prog2 128 178 1976.25 1985.15 506
prog2 128 182 1976.25 1985.15 507
prog2 128 184 1976.25 1985.15 508
prog2 128 193 1976.25 1985.15 509
prog2 128 196 1976.25 1985.15 510
prog2 132 134 1976.25 1985.15 511
prog2 132 136 1976.25 1985.15 512
prog2 132 138 1976.25 1985.15 513
prog2 132 142 1976.25 1985.15 514
prog2 132 144 1976.25 1985.15 515
prog2 132 146 1976.25 1985.15 516
prog2 132 156 1976.25 1985.15 517
prog2 132 158 1976.25 1985.15 518
prog2 132 172 1976.25 1985.15 519
prog2 132 174 1976.25 1985.15 520
prog2 132 178 1976.25 1985.15 521
prog2 132 182 1976.25 1985.15 522
prog2 132 184 1976.25 1985.15 523
prog2 132 193 1976.25 1985.15 524
prog2 132 196 1976.25 1985.15 525
prog2 134 136 1976.25 1985.15 526
prog2 134 138 1976.25 1985.15 527
prog2 134 142 1976.25 1985.15 528
prog2 134 144 1976.25 1985.15 529
prog2 134 146 1976.25 1985.15 530
prog2 134 156 1976.25 1985.15 531
prog2 134 158 1976.25 1985.15 532
prog2 134 172 1976.25 1985.15 533
prog2 134 174 1976.25 1985.15 534
prog2 134 178 1976.25 1985.15 535
prog2 134 182 1976.25 1985.15 536
prog2 134 184 1976.25 1985.15 537
prog2 134 193 1976.25 1985.15 538
prog2 134 196 1976.25 1985.15 539
prog2 136 138 1976.25 1985.15 540
prog2 136 142 1976.25 1985.15 541
prog2 136 144 1976.25 1985.15 542
prog2 136 146 1976.25 1985.15 543
prog2 136 156 1976.25 1985.15 544
prog2 136 158 1976.25 1985.15 545
prog2 136 172 1976.25 1985.15 546
prog2 136 174 1976.25 1985.15 547
prog2 136 178 1976.25 1985.15 548
prog2 136 182 1976.25 1985.15 549
prog2 136 184 1976.25 1985.15 550
prog2 136 193 1976.25 1985.15 551
prog2 136 196 1976.25 1985.15 552
prog2 138 142 1976.25 1985.15 553
prog2 138 144 1976.25 1985.15 554
prog2 138 146 1976.25 1985.15 555
prog2 138 156 1976.25 1985.15 556
prog2 138 158 1976.25 1985.15 557
prog2 138 172 1976.25 1985.15 558
prog2 138 174 1976.25 1985.15 559
prog2 138 178 1976.25 1985.15 560
prog2 138 182 1976.25 1985.15 561
prog2 138 184 1976.25 1985.15 562
prog2 138 193 1976.25 1985.15 563
prog2 138 196 1976.25 1985.15 564
prog2 142 144 1976.25 1985.15 565
prog2 142 146 1976.25 1985.15 566
prog2 142 156 1976.25 1985.15 567
prog2 142 158 1976.25 1985.15 568
prog2 142 172 1976.25 1985.15 569
prog2 142 174 1976.25 1985.15 570
prog2 142 178 1976.25 1985.15 571
prog2 142 182 1976.25 1985.15 572
prog2 142 184 1976.25 1985.15 573
prog2 142 193 1976.25 1985.15 574
prog2 142 196 1976.25 1985.15 575
prog2 144 146 1976.25 1985.15 576
prog2 144 156 1976.25 1985.15 577
prog2 144 158 1976.25 1985.15 578
prog2 144 172 1976.25 1985.15 579
prog2 144 174 1976.25 1985.15 580
prog2 144 178 1976.25 1985.15 581
prog2 144 182 1976.25 1985.15 582
prog2 144 184 1976.25 1985.15 583
prog2 144 193 1976.25 1985.15 584
prog2 144 196 1976.25 1985.15 585
prog2 146 156 1976.25 1985.15 586
prog2 146 158 1976.25 1985.15 587
prog2 146 172 1976.25 1985.15 588
prog2 146 174 1976.25 1985.15 589
prog2 146 178 1976.25 1985.15 590
prog2 146 182 1976.25 1985.15 591
prog2 146 184 1976.25 1985.15 592
prog2 146 193 1976.25 1985.15 593
prog2 146 196 1976.25 1985.15 594
prog2 156 158 1976.25 1985.15 595
prog2 156 172 1976.25 1985.15 596
prog2 156 174 1976.25 1985.15 597
prog2 156 178 1976.25 1985.15 598
prog2 156 182 1976.25 1985.15 599
prog2 156 184 1976.25 1985.15 600
prog2 156 193 1976.25 1985.15 601
prog2 156 196 1976.25 1985.15 602
prog2 158 172 1976.25 1985.15 603
prog2 158 174 1976.25 1985.15 604
prog2 158 178 1976.25 1985.15 605
prog2 158 182 1976.25 1985.15 606
prog2 158 184 1976.25 1985.15 607
prog2 158 193 1976.25 1985.15 608
prog2 158 196 1976.25 1985.15 609
prog2 172 174 1976.25 1985.15 610
prog2 172 178 1976.25 1985.15 611
prog2 172 182 1976.25 1985.15 612
prog2 172 184 1976.25 1985.15 613
prog2 172 193 1976.25 1985.15 614
prog2 172 196 1976.25 1985.15 615
prog2 174 178 1976.25 1985.15 616
prog2 174 182 1976.25 1985.15 617
prog2 174 184 1976.25 1985.15 618
prog2 174 193 1976.25 1985.15 619
prog2 174 196 1976.25 1985.15 620
prog2 178 182 1976.25 1985.15 621
prog2 178 184 1976.25 1985.15 622
prog2 178 193 1976.25 1985.15 623
prog2 178 196 1976.25 1985.15 624
prog2 182 184 1976.25 1985.15 625
prog2 182 193 1976.25 1985.15 626
prog2 182 196 1976.25 1985.15 627
prog2 184 193 1976.25 1985.15 628
prog2 184 196 1976.25 1985.15 629
prog2 193 196 1976.25 1985.15 630

prog2 111 112 1985.15 1995.15 631
prog2 111 122 1985.15 1995.15 632
prog2 111 124 1985.15 1995.15 633
prog2 111 128 1985.15 1995.15 634
prog2 111 132 1985.15 1995.15 635
prog2 111 134 1985.15 1995.15 636
prog2 111 136 1985.15 1995.15 637
prog2 111 138 1985.15 1995.15 638
prog2 111 142 1985.15 1995.15 639
prog2 111 144 1985.15 1995.15 640
prog2 111 146 1985.15 1995.15 641
prog2 111 156 1985.15 1995.15 642
prog2 111 158 1985.15 1995.15 643
prog2 111 172 1985.15 1995.15 644
prog2 111 174 1985.15 1995.15 645
prog2 111 178 1985.15 1995.15 646
prog2 111 182 1985.15 1995.15 647
prog2 111 184 1985.15 1995.15 648
prog2 111 193 1985.15 1995.15 649
prog2 111 196 1985.15 1995.15 650
prog2 112 122 1985.15 1995.15 651
prog2 112 124 1985.15 1995.15 652
prog2 112 128 1985.15 1995.15 653
prog2 112 132 1985.15 1995.15 654
prog2 112 134 1985.15 1995.15 655
prog2 112 136 1985.15 1995.15 656
prog2 112 138 1985.15 1995.15 657
prog2 112 142 1985.15 1995.15 658
prog2 112 144 1985.15 1995.15 659
prog2 112 146 1985.15 1995.15 660
prog2 112 156 1985.15 1995.15 661
prog2 112 158 1985.15 1995.15 662
prog2 112 172 1985.15 1995.15 663
prog2 112 174 1985.15 1995.15 664
prog2 112 178 1985.15 1995.15 665
prog2 112 182 1985.15 1995.15 666
prog2 112 184 1985.15 1995.15 667
prog2 112 193 1985.15 1995.15 668
prog2 112 196 1985.15 1995.15 669
prog2 122 124 1985.15 1995.15 670
prog2 122 128 1985.15 1995.15 671
prog2 122 132 1985.15 1995.15 672
prog2 122 134 1985.15 1995.15 673
prog2 122 136 1985.15 1995.15 674
prog2 122 138 1985.15 1995.15 675
prog2 122 142 1985.15 1995.15 676
prog2 122 144 1985.15 1995.15 677
prog2 122 146 1985.15 1995.15 678
prog2 122 156 1985.15 1995.15 679
prog2 122 158 1985.15 1995.15 680
prog2 122 172 1985.15 1995.15 681
prog2 122 174 1985.15 1995.15 682
prog2 122 178 1985.15 1995.15 683
prog2 122 182 1985.15 1995.15 684
prog2 122 184 1985.15 1995.15 685
prog2 122 193 1985.15 1995.15 686
prog2 122 196 1985.15 1995.15 687
prog2 124 128 1985.15 1995.15 688
prog2 124 132 1985.15 1995.15 689
prog2 124 134 1985.15 1995.15 690
prog2 124 136 1985.15 1995.15 691
prog2 124 138 1985.15 1995.15 692
prog2 124 142 1985.15 1995.15 693
prog2 124 144 1985.15 1995.15 694
prog2 124 146 1985.15 1995.15 695
prog2 124 156 1985.15 1995.15 696
prog2 124 158 1985.15 1995.15 697
prog2 124 172 1985.15 1995.15 698
prog2 124 174 1985.15 1995.15 699
prog2 124 178 1985.15 1995.15 700
prog2 124 182 1985.15 1995.15 701
prog2 124 184 1985.15 1995.15 702
prog2 124 193 1985.15 1995.15 703
prog2 124 196 1985.15 1995.15 704
prog2 128 132 1985.15 1995.15 705
prog2 128 134 1985.15 1995.15 706
prog2 128 136 1985.15 1995.15 707
prog2 128 138 1985.15 1995.15 708
prog2 128 142 1985.15 1995.15 709
prog2 128 144 1985.15 1995.15 710
prog2 128 146 1985.15 1995.15 711
prog2 128 156 1985.15 1995.15 712
prog2 128 158 1985.15 1995.15 713
prog2 128 172 1985.15 1995.15 714
prog2 128 174 1985.15 1995.15 715
prog2 128 178 1985.15 1995.15 716
prog2 128 182 1985.15 1995.15 717
prog2 128 184 1985.15 1995.15 718
prog2 128 193 1985.15 1995.15 719
prog2 128 196 1985.15 1995.15 720
prog2 132 134 1985.15 1995.15 721
prog2 132 136 1985.15 1995.15 722
prog2 132 138 1985.15 1995.15 723
prog2 132 142 1985.15 1995.15 724
prog2 132 144 1985.15 1995.15 725
prog2 132 146 1985.15 1995.15 726
prog2 132 156 1985.15 1995.15 727
prog2 132 158 1985.15 1995.15 728
prog2 132 172 1985.15 1995.15 729
prog2 132 174 1985.15 1995.15 730
prog2 132 178 1985.15 1995.15 731
prog2 132 182 1985.15 1995.15 732
prog2 132 184 1985.15 1995.15 733
prog2 132 193 1985.15 1995.15 734
prog2 132 196 1985.15 1995.15 735
prog2 134 136 1985.15 1995.15 736
prog2 134 138 1985.15 1995.15 737
prog2 134 142 1985.15 1995.15 738
prog2 134 144 1985.15 1995.15 739
prog2 134 146 1985.15 1995.15 740
prog2 134 156 1985.15 1995.15 741
prog2 134 158 1985.15 1995.15 742
prog2 134 172 1985.15 1995.15 743
prog2 134 174 1985.15 1995.15 744
prog2 134 178 1985.15 1995.15 745
prog2 134 182 1985.15 1995.15 746
prog2 134 184 1985.15 1995.15 747
prog2 134 193 1985.15 1995.15 748
prog2 134 196 1985.15 1995.15 749
prog2 136 138 1985.15 1995.15 750
prog2 136 142 1985.15 1995.15 751
prog2 136 144 1985.15 1995.15 752
prog2 136 146 1985.15 1995.15 753
prog2 136 156 1985.15 1995.15 754
prog2 136 158 1985.15 1995.15 755
prog2 136 172 1985.15 1995.15 756
prog2 136 174 1985.15 1995.15 757
prog2 136 178 1985.15 1995.15 758
prog2 136 182 1985.15 1995.15 759
prog2 136 184 1985.15 1995.15 760
prog2 136 193 1985.15 1995.15 761
prog2 136 196 1985.15 1995.15 762
prog2 138 142 1985.15 1995.15 763
prog2 138 144 1985.15 1995.15 764
prog2 138 146 1985.15 1995.15 765
prog2 138 156 1985.15 1995.15 766
prog2 138 158 1985.15 1995.15 767
prog2 138 172 1985.15 1995.15 768
prog2 138 174 1985.15 1995.15 769
prog2 138 178 1985.15 1995.15 770
prog2 138 182 1985.15 1995.15 771
prog2 138 184 1985.15 1995.15 772
prog2 138 193 1985.15 1995.15 773
prog2 138 196 1985.15 1995.15 774
prog2 142 144 1985.15 1995.15 775
prog2 142 146 1985.15 1995.15 776
prog2 142 156 1985.15 1995.15 777
prog2 142 158 1985.15 1995.15 778
prog2 142 172 1985.15 1995.15 779
prog2 142 174 1985.15 1995.15 780
prog2 142 178 1985.15 1995.15 781
prog2 142 182 1985.15 1995.15 782
prog2 142 184 1985.15 1995.15 783
prog2 142 193 1985.15 1995.15 784
prog2 142 196 1985.15 1995.15 785
prog2 144 146 1985.15 1995.15 786
prog2 144 156 1985.15 1995.15 787
prog2 144 158 1985.15 1995.15 788
prog2 144 172 1985.15 1995.15 789
prog2 144 174 1985.15 1995.15 790
prog2 144 178 1985.15 1995.15 791
prog2 144 182 1985.15 1995.15 792
prog2 144 184 1985.15 1995.15 793
prog2 144 193 1985.15 1995.15 794
prog2 144 196 1985.15 1995.15 795
prog2 146 156 1985.15 1995.15 796
prog2 146 158 1985.15 1995.15 797
prog2 146 172 1985.15 1995.15 798
prog2 146 174 1985.15 1995.15 799
prog2 146 178 1985.15 1995.15 800
prog2 146 182 1985.15 1995.15 801
prog2 146 184 1985.15 1995.15 802
prog2 146 193 1985.15 1995.15 803
prog2 146 196 1985.15 1995.15 804
prog2 156 158 1985.15 1995.15 805
prog2 156 172 1985.15 1995.15 806
prog2 156 174 1985.15 1995.15 807
prog2 156 178 1985.15 1995.15 808
prog2 156 182 1985.15 1995.15 809
prog2 156 184 1985.15 1995.15 810
prog2 156 193 1985.15 1995.15 811
prog2 156 196 1985.15 1995.15 812
prog2 158 172 1985.15 1995.15 813
prog2 158 174 1985.15 1995.15 814
prog2 158 178 1985.15 1995.15 815
prog2 158 182 1985.15 1995.15 816
prog2 158 184 1985.15 1995.15 817
prog2 158 193 1985.15 1995.15 818
prog2 158 196 1985.15 1995.15 819
prog2 172 174 1985.15 1995.15 820
prog2 172 178 1985.15 1995.15 821
prog2 172 182 1985.15 1995.15 822
prog2 172 184 1985.15 1995.15 823
prog2 172 193 1985.15 1995.15 824
prog2 172 196 1985.15 1995.15 825
prog2 174 178 1985.15 1995.15 826
prog2 174 182 1985.15 1995.15 827
prog2 174 184 1985.15 1995.15 828
prog2 174 193 1985.15 1995.15 829
prog2 174 196 1985.15 1995.15 830
prog2 178 182 1985.15 1995.15 831
prog2 178 184 1985.15 1995.15 832
prog2 178 193 1985.15 1995.15 833
prog2 178 196 1985.15 1995.15 834
prog2 182 184 1985.15 1995.15 835
prog2 182 193 1985.15 1995.15 836
prog2 182 196 1985.15 1995.15 837
prog2 184 193 1985.15 1995.15 838
prog2 184 196 1985.15 1995.15 839
prog2 193 196 1985.15 1995.15 840
*
* Write out the data (and a few auxiliaries)
*
g period=1 in 1/210
replace period=2 in 211/420
replace period=3 in 421/630
replace period=4 in 631/840

compress
sort count1 count2 period
outfile period count1 count2 dy di de du ty ti te tu hy hi he hu sy si se su oy oi oe ou oilpxmy doilpxmy in 1/840 using \res\oca\data\ycorr,replace dictionary
drop _all
*
* Now combine the two data sets
*
infile using \res\oca\data\weights
compress
sort count1 count2 period
save \res\oca\data\crap,replace
drop _all

infile using \res\oca\data\ycorr
compress
sort count1 count2 period

merge count1 count2 period using \res\oca\data\crap
tab _merge
drop _merge

compress
sort count1 count2 period
save \res\oca\data\datav3,replace
drop _all
!del \res\oca\data\crap*.*
!del crap*.*
*
* Now add the population and real gdp per capita stuff
*
* Read in the data and clean it up
*
use \res\oca\data\datav2a
drop if ifscode==199
drop if ifscode==186
drop if ifscode==181
drop if ifscode==176
*
* Create the empty period-average variables
*
g c1pop=.
g c2pop=.
g c1rgdpch=.
g c2rgdpch=.

label var c1pop "Population, Country 1"
label var c2pop "Population, Country 2"
label var c1rgdpch "Real GDP per capita, Country 1"
label var c2rgdpch "Real GDP per capita, Country 2"

g count1=.
g count2=.

label var count1 "Exporter or Importer"
label var count2 "Exportee or Import Sender"
*
* A program to average POP and RGDPCH and compute a supply shock
*
program define prog3 /* country1 country2 start end obs*/
	quietly replace count1=`1' in `5'/`5'
	quietly replace count2=`2' in `5'/`5'
	quietly sum pop if ifscode==`1'&(date>`3'&date<`4')
	quietly replace c1pop=_result(3) in `5'/`5'
	quietly sum pop if ifscode==`2'&(date>`3'&date<`4')
	quietly replace c2pop=_result(3) in `5'/`5'
	quietly sum rgdpch if ifscode==`1'&(date>`3'&date<`4')
	quietly replace c1rgdpch=_result(3) in `5'/`5'
	quietly sum rgdpch if ifscode==`2'&(date>`3'&date<`4')
	quietly replace c2rgdpch=_result(3) in `5'/`5'
	end
*
* Compute the averages
*
prog3 111 112 1950.05 1967.35 1
prog3 111 122 1950.05 1967.35 2
prog3 111 124 1950.05 1967.35 3
prog3 111 128 1950.05 1967.35 4
prog3 111 132 1950.05 1967.35 5
prog3 111 134 1950.05 1967.35 6
prog3 111 136 1950.05 1967.35 7
prog3 111 138 1950.05 1967.35 8
prog3 111 142 1950.05 1967.35 9
prog3 111 144 1950.05 1967.35 10
prog3 111 146 1950.05 1967.35 11
prog3 111 156 1950.05 1967.35 12
prog3 111 158 1950.05 1967.35 13
prog3 111 172 1950.05 1967.35 14
prog3 111 174 1950.05 1967.35 15
prog3 111 178 1950.05 1967.35 16
prog3 111 182 1950.05 1967.35 17
prog3 111 184 1950.05 1967.35 18
prog3 111 193 1950.05 1967.35 19
prog3 111 196 1950.05 1967.35 20
prog3 112 122 1950.05 1967.35 21
prog3 112 124 1950.05 1967.35 22
prog3 112 128 1950.05 1967.35 23
prog3 112 132 1950.05 1967.35 24
prog3 112 134 1950.05 1967.35 25
prog3 112 136 1950.05 1967.35 26
prog3 112 138 1950.05 1967.35 27
prog3 112 142 1950.05 1967.35 28
prog3 112 144 1950.05 1967.35 29
prog3 112 146 1950.05 1967.35 30
prog3 112 156 1950.05 1967.35 31
prog3 112 158 1950.05 1967.35 32
prog3 112 172 1950.05 1967.35 33
prog3 112 174 1950.05 1967.35 34
prog3 112 178 1950.05 1967.35 35
prog3 112 182 1950.05 1967.35 36
prog3 112 184 1950.05 1967.35 37
prog3 112 193 1950.05 1967.35 38
prog3 112 196 1950.05 1967.35 39
prog3 122 124 1950.05 1967.35 40
prog3 122 128 1950.05 1967.35 41
prog3 122 132 1950.05 1967.35 42
prog3 122 134 1950.05 1967.35 43
prog3 122 136 1950.05 1967.35 44
prog3 122 138 1950.05 1967.35 45
prog3 122 142 1950.05 1967.35 46
prog3 122 144 1950.05 1967.35 47
prog3 122 146 1950.05 1967.35 48
prog3 122 156 1950.05 1967.35 49
prog3 122 158 1950.05 1967.35 50
prog3 122 172 1950.05 1967.35 51
prog3 122 174 1950.05 1967.35 52
prog3 122 178 1950.05 1967.35 53
prog3 122 182 1950.05 1967.35 54
prog3 122 184 1950.05 1967.35 55
prog3 122 193 1950.05 1967.35 56
prog3 122 196 1950.05 1967.35 57
prog3 124 128 1950.05 1967.35 58
prog3 124 132 1950.05 1967.35 59
prog3 124 134 1950.05 1967.35 60
prog3 124 136 1950.05 1967.35 61
prog3 124 138 1950.05 1967.35 62
prog3 124 142 1950.05 1967.35 63
prog3 124 144 1950.05 1967.35 64
prog3 124 146 1950.05 1967.35 65
prog3 124 156 1950.05 1967.35 66
prog3 124 158 1950.05 1967.35 67
prog3 124 172 1950.05 1967.35 68
prog3 124 174 1950.05 1967.35 69
prog3 124 178 1950.05 1967.35 70
prog3 124 182 1950.05 1967.35 71
prog3 124 184 1950.05 1967.35 72
prog3 124 193 1950.05 1967.35 73
prog3 124 196 1950.05 1967.35 74
prog3 128 132 1950.05 1967.35 75
prog3 128 134 1950.05 1967.35 76
prog3 128 136 1950.05 1967.35 77
prog3 128 138 1950.05 1967.35 78
prog3 128 142 1950.05 1967.35 79
prog3 128 144 1950.05 1967.35 80
prog3 128 146 1950.05 1967.35 81
prog3 128 156 1950.05 1967.35 82
prog3 128 158 1950.05 1967.35 83
prog3 128 172 1950.05 1967.35 84
prog3 128 174 1950.05 1967.35 85
prog3 128 178 1950.05 1967.35 86
prog3 128 182 1950.05 1967.35 87
prog3 128 184 1950.05 1967.35 88
prog3 128 193 1950.05 1967.35 89
prog3 128 196 1950.05 1967.35 90
prog3 132 134 1950.05 1967.35 91
prog3 132 136 1950.05 1967.35 92
prog3 132 138 1950.05 1967.35 93
prog3 132 142 1950.05 1967.35 94
prog3 132 144 1950.05 1967.35 95
prog3 132 146 1950.05 1967.35 96
prog3 132 156 1950.05 1967.35 97
prog3 132 158 1950.05 1967.35 98
prog3 132 172 1950.05 1967.35 99
prog3 132 174 1950.05 1967.35 100
prog3 132 178 1950.05 1967.35 101
prog3 132 182 1950.05 1967.35 102
prog3 132 184 1950.05 1967.35 103
prog3 132 193 1950.05 1967.35 104
prog3 132 196 1950.05 1967.35 105
prog3 134 136 1950.05 1967.35 106
prog3 134 138 1950.05 1967.35 107
prog3 134 142 1950.05 1967.35 108
prog3 134 144 1950.05 1967.35 109
prog3 134 146 1950.05 1967.35 110
prog3 134 156 1950.05 1967.35 111
prog3 134 158 1950.05 1967.35 112
prog3 134 172 1950.05 1967.35 113
prog3 134 174 1950.05 1967.35 114
prog3 134 178 1950.05 1967.35 115
prog3 134 182 1950.05 1967.35 116
prog3 134 184 1950.05 1967.35 117
prog3 134 193 1950.05 1967.35 118
prog3 134 196 1950.05 1967.35 119
prog3 136 138 1950.05 1967.35 120
prog3 136 142 1950.05 1967.35 121
prog3 136 144 1950.05 1967.35 122
prog3 136 146 1950.05 1967.35 123
prog3 136 156 1950.05 1967.35 124
prog3 136 158 1950.05 1967.35 125
prog3 136 172 1950.05 1967.35 126
prog3 136 174 1950.05 1967.35 127
prog3 136 178 1950.05 1967.35 128
prog3 136 182 1950.05 1967.35 129
prog3 136 184 1950.05 1967.35 130
prog3 136 193 1950.05 1967.35 131
prog3 136 196 1950.05 1967.35 132
prog3 138 142 1950.05 1967.35 133
prog3 138 144 1950.05 1967.35 134
prog3 138 146 1950.05 1967.35 135
prog3 138 156 1950.05 1967.35 136
prog3 138 158 1950.05 1967.35 137
prog3 138 172 1950.05 1967.35 138
prog3 138 174 1950.05 1967.35 139
prog3 138 178 1950.05 1967.35 140
prog3 138 182 1950.05 1967.35 141
prog3 138 184 1950.05 1967.35 142
prog3 138 193 1950.05 1967.35 143
prog3 138 196 1950.05 1967.35 144
prog3 142 144 1950.05 1967.35 145
prog3 142 146 1950.05 1967.35 146
prog3 142 156 1950.05 1967.35 147
prog3 142 158 1950.05 1967.35 148
prog3 142 172 1950.05 1967.35 149
prog3 142 174 1950.05 1967.35 150
prog3 142 178 1950.05 1967.35 151
prog3 142 182 1950.05 1967.35 152
prog3 142 184 1950.05 1967.35 153
prog3 142 193 1950.05 1967.35 154
prog3 142 196 1950.05 1967.35 155
prog3 144 146 1950.05 1967.35 156
prog3 144 156 1950.05 1967.35 157
prog3 144 158 1950.05 1967.35 158
prog3 144 172 1950.05 1967.35 159
prog3 144 174 1950.05 1967.35 160
prog3 144 178 1950.05 1967.35 161
prog3 144 182 1950.05 1967.35 162
prog3 144 184 1950.05 1967.35 163
prog3 144 193 1950.05 1967.35 164
prog3 144 196 1950.05 1967.35 165
prog3 146 156 1950.05 1967.35 166
prog3 146 158 1950.05 1967.35 167
prog3 146 172 1950.05 1967.35 168
prog3 146 174 1950.05 1967.35 169
prog3 146 178 1950.05 1967.35 170
prog3 146 182 1950.05 1967.35 171
prog3 146 184 1950.05 1967.35 172
prog3 146 193 1950.05 1967.35 173
prog3 146 196 1950.05 1967.35 174
prog3 156 158 1950.05 1967.35 175
prog3 156 172 1950.05 1967.35 176
prog3 156 174 1950.05 1967.35 177
prog3 156 178 1950.05 1967.35 178
prog3 156 182 1950.05 1967.35 179
prog3 156 184 1950.05 1967.35 180
prog3 156 193 1950.05 1967.35 181
prog3 156 196 1950.05 1967.35 182
prog3 158 172 1950.05 1967.35 183
prog3 158 174 1950.05 1967.35 184
prog3 158 178 1950.05 1967.35 185
prog3 158 182 1950.05 1967.35 186
prog3 158 184 1950.05 1967.35 187
prog3 158 193 1950.05 1967.35 188
prog3 158 196 1950.05 1967.35 189
prog3 172 174 1950.05 1967.35 190
prog3 172 178 1950.05 1967.35 191
prog3 172 182 1950.05 1967.35 192
prog3 172 184 1950.05 1967.35 193
prog3 172 193 1950.05 1967.35 194
prog3 172 196 1950.05 1967.35 195
prog3 174 178 1950.05 1967.35 196
prog3 174 182 1950.05 1967.35 197
prog3 174 184 1950.05 1967.35 198
prog3 174 193 1950.05 1967.35 199
prog3 174 196 1950.05 1967.35 200
prog3 178 182 1950.05 1967.35 201
prog3 178 184 1950.05 1967.35 202
prog3 178 193 1950.05 1967.35 203
prog3 178 196 1950.05 1967.35 204
prog3 182 184 1950.05 1967.35 205
prog3 182 193 1950.05 1967.35 206
prog3 182 196 1950.05 1967.35 207
prog3 184 193 1950.05 1967.35 208
prog3 184 196 1950.05 1967.35 209
prog3 193 196 1950.05 1967.35 210

prog3 111 112 1967.35 1976.25 211
prog3 111 122 1967.35 1976.25 212
prog3 111 124 1967.35 1976.25 213
prog3 111 128 1967.35 1976.25 214
prog3 111 132 1967.35 1976.25 215
prog3 111 134 1967.35 1976.25 216
prog3 111 136 1967.35 1976.25 217
prog3 111 138 1967.35 1976.25 218
prog3 111 142 1967.35 1976.25 219
prog3 111 144 1967.35 1976.25 220
prog3 111 146 1967.35 1976.25 221
prog3 111 156 1967.35 1976.25 222
prog3 111 158 1967.35 1976.25 223
prog3 111 172 1967.35 1976.25 224
prog3 111 174 1967.35 1976.25 225
prog3 111 178 1967.35 1976.25 226
prog3 111 182 1967.35 1976.25 227
prog3 111 184 1967.35 1976.25 228
prog3 111 193 1967.35 1976.25 229
prog3 111 196 1967.35 1976.25 230
prog3 112 122 1967.35 1976.25 231
prog3 112 124 1967.35 1976.25 232
prog3 112 128 1967.35 1976.25 233
prog3 112 132 1967.35 1976.25 234
prog3 112 134 1967.35 1976.25 235
prog3 112 136 1967.35 1976.25 236
prog3 112 138 1967.35 1976.25 237
prog3 112 142 1967.35 1976.25 238
prog3 112 144 1967.35 1976.25 239
prog3 112 146 1967.35 1976.25 240
prog3 112 156 1967.35 1976.25 241
prog3 112 158 1967.35 1976.25 242
prog3 112 172 1967.35 1976.25 243
prog3 112 174 1967.35 1976.25 244
prog3 112 178 1967.35 1976.25 245
prog3 112 182 1967.35 1976.25 246
prog3 112 184 1967.35 1976.25 247
prog3 112 193 1967.35 1976.25 248
prog3 112 196 1967.35 1976.25 249
prog3 122 124 1967.35 1976.25 250
prog3 122 128 1967.35 1976.25 251
prog3 122 132 1967.35 1976.25 252
prog3 122 134 1967.35 1976.25 253
prog3 122 136 1967.35 1976.25 254
prog3 122 138 1967.35 1976.25 255
prog3 122 142 1967.35 1976.25 256
prog3 122 144 1967.35 1976.25 257
prog3 122 146 1967.35 1976.25 258
prog3 122 156 1967.35 1976.25 259
prog3 122 158 1967.35 1976.25 260
prog3 122 172 1967.35 1976.25 261
prog3 122 174 1967.35 1976.25 262
prog3 122 178 1967.35 1976.25 263
prog3 122 182 1967.35 1976.25 264
prog3 122 184 1967.35 1976.25 265
prog3 122 193 1967.35 1976.25 266
prog3 122 196 1967.35 1976.25 267
prog3 124 128 1967.35 1976.25 268
prog3 124 132 1967.35 1976.25 269
prog3 124 134 1967.35 1976.25 270
prog3 124 136 1967.35 1976.25 271
prog3 124 138 1967.35 1976.25 272
prog3 124 142 1967.35 1976.25 273
prog3 124 144 1967.35 1976.25 274
prog3 124 146 1967.35 1976.25 275
prog3 124 156 1967.35 1976.25 276
prog3 124 158 1967.35 1976.25 277
prog3 124 172 1967.35 1976.25 278
prog3 124 174 1967.35 1976.25 279
prog3 124 178 1967.35 1976.25 280
prog3 124 182 1967.35 1976.25 281
prog3 124 184 1967.35 1976.25 282
prog3 124 193 1967.35 1976.25 283
prog3 124 196 1967.35 1976.25 284
prog3 128 132 1967.35 1976.25 285
prog3 128 134 1967.35 1976.25 286
prog3 128 136 1967.35 1976.25 287
prog3 128 138 1967.35 1976.25 288
prog3 128 142 1967.35 1976.25 289
prog3 128 144 1967.35 1976.25 290
prog3 128 146 1967.35 1976.25 291
prog3 128 156 1967.35 1976.25 292
prog3 128 158 1967.35 1976.25 293
prog3 128 172 1967.35 1976.25 294
prog3 128 174 1967.35 1976.25 295
prog3 128 178 1967.35 1976.25 296
prog3 128 182 1967.35 1976.25 297
prog3 128 184 1967.35 1976.25 298
prog3 128 193 1967.35 1976.25 299
prog3 128 196 1967.35 1976.25 300
prog3 132 134 1967.35 1976.25 301
prog3 132 136 1967.35 1976.25 302
prog3 132 138 1967.35 1976.25 303
prog3 132 142 1967.35 1976.25 304
prog3 132 144 1967.35 1976.25 305
prog3 132 146 1967.35 1976.25 306
prog3 132 156 1967.35 1976.25 307
prog3 132 158 1967.35 1976.25 308
prog3 132 172 1967.35 1976.25 309
prog3 132 174 1967.35 1976.25 310
prog3 132 178 1967.35 1976.25 311
prog3 132 182 1967.35 1976.25 312
prog3 132 184 1967.35 1976.25 313
prog3 132 193 1967.35 1976.25 314
prog3 132 196 1967.35 1976.25 315
prog3 134 136 1967.35 1976.25 316
prog3 134 138 1967.35 1976.25 317
prog3 134 142 1967.35 1976.25 318
prog3 134 144 1967.35 1976.25 319
prog3 134 146 1967.35 1976.25 320
prog3 134 156 1967.35 1976.25 321
prog3 134 158 1967.35 1976.25 322
prog3 134 172 1967.35 1976.25 323
prog3 134 174 1967.35 1976.25 324
prog3 134 178 1967.35 1976.25 325
prog3 134 182 1967.35 1976.25 326
prog3 134 184 1967.35 1976.25 327
prog3 134 193 1967.35 1976.25 328
prog3 134 196 1967.35 1976.25 329
prog3 136 138 1967.35 1976.25 330
prog3 136 142 1967.35 1976.25 331
prog3 136 144 1967.35 1976.25 332
prog3 136 146 1967.35 1976.25 333
prog3 136 156 1967.35 1976.25 334
prog3 136 158 1967.35 1976.25 335
prog3 136 172 1967.35 1976.25 336
prog3 136 174 1967.35 1976.25 337
prog3 136 178 1967.35 1976.25 338
prog3 136 182 1967.35 1976.25 339
prog3 136 184 1967.35 1976.25 340
prog3 136 193 1967.35 1976.25 341
prog3 136 196 1967.35 1976.25 342
prog3 138 142 1967.35 1976.25 343
prog3 138 144 1967.35 1976.25 344
prog3 138 146 1967.35 1976.25 345
prog3 138 156 1967.35 1976.25 346
prog3 138 158 1967.35 1976.25 347
prog3 138 172 1967.35 1976.25 348
prog3 138 174 1967.35 1976.25 349
prog3 138 178 1967.35 1976.25 350
prog3 138 182 1967.35 1976.25 351
prog3 138 184 1967.35 1976.25 352
prog3 138 193 1967.35 1976.25 353
prog3 138 196 1967.35 1976.25 354
prog3 142 144 1967.35 1976.25 355
prog3 142 146 1967.35 1976.25 356
prog3 142 156 1967.35 1976.25 357
prog3 142 158 1967.35 1976.25 358
prog3 142 172 1967.35 1976.25 359
prog3 142 174 1967.35 1976.25 360
prog3 142 178 1967.35 1976.25 361
prog3 142 182 1967.35 1976.25 362
prog3 142 184 1967.35 1976.25 363
prog3 142 193 1967.35 1976.25 364
prog3 142 196 1967.35 1976.25 365
prog3 144 146 1967.35 1976.25 366
prog3 144 156 1967.35 1976.25 367
prog3 144 158 1967.35 1976.25 368
prog3 144 172 1967.35 1976.25 369
prog3 144 174 1967.35 1976.25 370
prog3 144 178 1967.35 1976.25 371
prog3 144 182 1967.35 1976.25 372
prog3 144 184 1967.35 1976.25 373
prog3 144 193 1967.35 1976.25 374
prog3 144 196 1967.35 1976.25 375
prog3 146 156 1967.35 1976.25 376
prog3 146 158 1967.35 1976.25 377
prog3 146 172 1967.35 1976.25 378
prog3 146 174 1967.35 1976.25 379
prog3 146 178 1967.35 1976.25 380
prog3 146 182 1967.35 1976.25 381
prog3 146 184 1967.35 1976.25 382
prog3 146 193 1967.35 1976.25 383
prog3 146 196 1967.35 1976.25 384
prog3 156 158 1967.35 1976.25 385
prog3 156 172 1967.35 1976.25 386
prog3 156 174 1967.35 1976.25 387
prog3 156 178 1967.35 1976.25 388
prog3 156 182 1967.35 1976.25 389
prog3 156 184 1967.35 1976.25 390
prog3 156 193 1967.35 1976.25 391
prog3 156 196 1967.35 1976.25 392
prog3 158 172 1967.35 1976.25 393
prog3 158 174 1967.35 1976.25 394
prog3 158 178 1967.35 1976.25 395
prog3 158 182 1967.35 1976.25 396
prog3 158 184 1967.35 1976.25 397
prog3 158 193 1967.35 1976.25 398
prog3 158 196 1967.35 1976.25 399
prog3 172 174 1967.35 1976.25 400
prog3 172 178 1967.35 1976.25 401
prog3 172 182 1967.35 1976.25 402
prog3 172 184 1967.35 1976.25 403
prog3 172 193 1967.35 1976.25 404
prog3 172 196 1967.35 1976.25 405
prog3 174 178 1967.35 1976.25 406
prog3 174 182 1967.35 1976.25 407
prog3 174 184 1967.35 1976.25 408
prog3 174 193 1967.35 1976.25 409
prog3 174 196 1967.35 1976.25 410
prog3 178 182 1967.35 1976.25 411
prog3 178 184 1967.35 1976.25 412
prog3 178 193 1967.35 1976.25 413
prog3 178 196 1967.35 1976.25 414
prog3 182 184 1967.35 1976.25 415
prog3 182 193 1967.35 1976.25 416
prog3 182 196 1967.35 1976.25 417
prog3 184 193 1967.35 1976.25 418
prog3 184 196 1967.35 1976.25 419
prog3 193 196 1967.35 1976.25 420

prog3 111 112 1976.25 1985.15 421
prog3 111 122 1976.25 1985.15 422
prog3 111 124 1976.25 1985.15 423
prog3 111 128 1976.25 1985.15 424
prog3 111 132 1976.25 1985.15 425
prog3 111 134 1976.25 1985.15 426
prog3 111 136 1976.25 1985.15 427
prog3 111 138 1976.25 1985.15 428
prog3 111 142 1976.25 1985.15 429
prog3 111 144 1976.25 1985.15 430
prog3 111 146 1976.25 1985.15 431
prog3 111 156 1976.25 1985.15 432
prog3 111 158 1976.25 1985.15 433
prog3 111 172 1976.25 1985.15 434
prog3 111 174 1976.25 1985.15 435
prog3 111 178 1976.25 1985.15 436
prog3 111 182 1976.25 1985.15 437
prog3 111 184 1976.25 1985.15 438
prog3 111 193 1976.25 1985.15 439
prog3 111 196 1976.25 1985.15 440
prog3 112 122 1976.25 1985.15 441
prog3 112 124 1976.25 1985.15 442
prog3 112 128 1976.25 1985.15 443
prog3 112 132 1976.25 1985.15 444
prog3 112 134 1976.25 1985.15 445
prog3 112 136 1976.25 1985.15 446
prog3 112 138 1976.25 1985.15 447
prog3 112 142 1976.25 1985.15 448
prog3 112 144 1976.25 1985.15 449
prog3 112 146 1976.25 1985.15 450
prog3 112 156 1976.25 1985.15 451
prog3 112 158 1976.25 1985.15 452
prog3 112 172 1976.25 1985.15 453
prog3 112 174 1976.25 1985.15 454
prog3 112 178 1976.25 1985.15 455
prog3 112 182 1976.25 1985.15 456
prog3 112 184 1976.25 1985.15 457
prog3 112 193 1976.25 1985.15 458
prog3 112 196 1976.25 1985.15 459
prog3 122 124 1976.25 1985.15 460
prog3 122 128 1976.25 1985.15 461
prog3 122 132 1976.25 1985.15 462
prog3 122 134 1976.25 1985.15 463
prog3 122 136 1976.25 1985.15 464
prog3 122 138 1976.25 1985.15 465
prog3 122 142 1976.25 1985.15 466
prog3 122 144 1976.25 1985.15 467
prog3 122 146 1976.25 1985.15 468
prog3 122 156 1976.25 1985.15 469
prog3 122 158 1976.25 1985.15 470
prog3 122 172 1976.25 1985.15 471
prog3 122 174 1976.25 1985.15 472
prog3 122 178 1976.25 1985.15 473
prog3 122 182 1976.25 1985.15 474
prog3 122 184 1976.25 1985.15 475
prog3 122 193 1976.25 1985.15 476
prog3 122 196 1976.25 1985.15 477
prog3 124 128 1976.25 1985.15 478
prog3 124 132 1976.25 1985.15 479
prog3 124 134 1976.25 1985.15 480
prog3 124 136 1976.25 1985.15 481
prog3 124 138 1976.25 1985.15 482
prog3 124 142 1976.25 1985.15 483
prog3 124 144 1976.25 1985.15 484
prog3 124 146 1976.25 1985.15 485
prog3 124 156 1976.25 1985.15 486
prog3 124 158 1976.25 1985.15 487
prog3 124 172 1976.25 1985.15 488
prog3 124 174 1976.25 1985.15 489
prog3 124 178 1976.25 1985.15 490
prog3 124 182 1976.25 1985.15 491
prog3 124 184 1976.25 1985.15 492
prog3 124 193 1976.25 1985.15 493
prog3 124 196 1976.25 1985.15 494
prog3 128 132 1976.25 1985.15 495
prog3 128 134 1976.25 1985.15 496
prog3 128 136 1976.25 1985.15 497
prog3 128 138 1976.25 1985.15 498
prog3 128 142 1976.25 1985.15 499
prog3 128 144 1976.25 1985.15 500
prog3 128 146 1976.25 1985.15 501
prog3 128 156 1976.25 1985.15 502
prog3 128 158 1976.25 1985.15 503
prog3 128 172 1976.25 1985.15 504
prog3 128 174 1976.25 1985.15 505
prog3 128 178 1976.25 1985.15 506
prog3 128 182 1976.25 1985.15 507
prog3 128 184 1976.25 1985.15 508
prog3 128 193 1976.25 1985.15 509
prog3 128 196 1976.25 1985.15 510
prog3 132 134 1976.25 1985.15 511
prog3 132 136 1976.25 1985.15 512
prog3 132 138 1976.25 1985.15 513
prog3 132 142 1976.25 1985.15 514
prog3 132 144 1976.25 1985.15 515
prog3 132 146 1976.25 1985.15 516
prog3 132 156 1976.25 1985.15 517
prog3 132 158 1976.25 1985.15 518
prog3 132 172 1976.25 1985.15 519
prog3 132 174 1976.25 1985.15 520
prog3 132 178 1976.25 1985.15 521
prog3 132 182 1976.25 1985.15 522
prog3 132 184 1976.25 1985.15 523
prog3 132 193 1976.25 1985.15 524
prog3 132 196 1976.25 1985.15 525
prog3 134 136 1976.25 1985.15 526
prog3 134 138 1976.25 1985.15 527
prog3 134 142 1976.25 1985.15 528
prog3 134 144 1976.25 1985.15 529
prog3 134 146 1976.25 1985.15 530
prog3 134 156 1976.25 1985.15 531
prog3 134 158 1976.25 1985.15 532
prog3 134 172 1976.25 1985.15 533
prog3 134 174 1976.25 1985.15 534
prog3 134 178 1976.25 1985.15 535
prog3 134 182 1976.25 1985.15 536
prog3 134 184 1976.25 1985.15 537
prog3 134 193 1976.25 1985.15 538
prog3 134 196 1976.25 1985.15 539
prog3 136 138 1976.25 1985.15 540
prog3 136 142 1976.25 1985.15 541
prog3 136 144 1976.25 1985.15 542
prog3 136 146 1976.25 1985.15 543
prog3 136 156 1976.25 1985.15 544
prog3 136 158 1976.25 1985.15 545
prog3 136 172 1976.25 1985.15 546
prog3 136 174 1976.25 1985.15 547
prog3 136 178 1976.25 1985.15 548
prog3 136 182 1976.25 1985.15 549
prog3 136 184 1976.25 1985.15 550
prog3 136 193 1976.25 1985.15 551
prog3 136 196 1976.25 1985.15 552
prog3 138 142 1976.25 1985.15 553
prog3 138 144 1976.25 1985.15 554
prog3 138 146 1976.25 1985.15 555
prog3 138 156 1976.25 1985.15 556
prog3 138 158 1976.25 1985.15 557
prog3 138 172 1976.25 1985.15 558
prog3 138 174 1976.25 1985.15 559
prog3 138 178 1976.25 1985.15 560
prog3 138 182 1976.25 1985.15 561
prog3 138 184 1976.25 1985.15 562
prog3 138 193 1976.25 1985.15 563
prog3 138 196 1976.25 1985.15 564
prog3 142 144 1976.25 1985.15 565
prog3 142 146 1976.25 1985.15 566
prog3 142 156 1976.25 1985.15 567
prog3 142 158 1976.25 1985.15 568
prog3 142 172 1976.25 1985.15 569
prog3 142 174 1976.25 1985.15 570
prog3 142 178 1976.25 1985.15 571
prog3 142 182 1976.25 1985.15 572
prog3 142 184 1976.25 1985.15 573
prog3 142 193 1976.25 1985.15 574
prog3 142 196 1976.25 1985.15 575
prog3 144 146 1976.25 1985.15 576
prog3 144 156 1976.25 1985.15 577
prog3 144 158 1976.25 1985.15 578
prog3 144 172 1976.25 1985.15 579
prog3 144 174 1976.25 1985.15 580
prog3 144 178 1976.25 1985.15 581
prog3 144 182 1976.25 1985.15 582
prog3 144 184 1976.25 1985.15 583
prog3 144 193 1976.25 1985.15 584
prog3 144 196 1976.25 1985.15 585
prog3 146 156 1976.25 1985.15 586
prog3 146 158 1976.25 1985.15 587
prog3 146 172 1976.25 1985.15 588
prog3 146 174 1976.25 1985.15 589
prog3 146 178 1976.25 1985.15 590
prog3 146 182 1976.25 1985.15 591
prog3 146 184 1976.25 1985.15 592
prog3 146 193 1976.25 1985.15 593
prog3 146 196 1976.25 1985.15 594
prog3 156 158 1976.25 1985.15 595
prog3 156 172 1976.25 1985.15 596
prog3 156 174 1976.25 1985.15 597
prog3 156 178 1976.25 1985.15 598
prog3 156 182 1976.25 1985.15 599
prog3 156 184 1976.25 1985.15 600
prog3 156 193 1976.25 1985.15 601
prog3 156 196 1976.25 1985.15 602
prog3 158 172 1976.25 1985.15 603
prog3 158 174 1976.25 1985.15 604
prog3 158 178 1976.25 1985.15 605
prog3 158 182 1976.25 1985.15 606
prog3 158 184 1976.25 1985.15 607
prog3 158 193 1976.25 1985.15 608
prog3 158 196 1976.25 1985.15 609
prog3 172 174 1976.25 1985.15 610
prog3 172 178 1976.25 1985.15 611
prog3 172 182 1976.25 1985.15 612
prog3 172 184 1976.25 1985.15 613
prog3 172 193 1976.25 1985.15 614
prog3 172 196 1976.25 1985.15 615
prog3 174 178 1976.25 1985.15 616
prog3 174 182 1976.25 1985.15 617
prog3 174 184 1976.25 1985.15 618
prog3 174 193 1976.25 1985.15 619
prog3 174 196 1976.25 1985.15 620
prog3 178 182 1976.25 1985.15 621
prog3 178 184 1976.25 1985.15 622
prog3 178 193 1976.25 1985.15 623
prog3 178 196 1976.25 1985.15 624
prog3 182 184 1976.25 1985.15 625
prog3 182 193 1976.25 1985.15 626
prog3 182 196 1976.25 1985.15 627
prog3 184 193 1976.25 1985.15 628
prog3 184 196 1976.25 1985.15 629
prog3 193 196 1976.25 1985.15 630

prog3 111 112 1985.15 1995.15 631
prog3 111 122 1985.15 1995.15 632
prog3 111 124 1985.15 1995.15 633
prog3 111 128 1985.15 1995.15 634
prog3 111 132 1985.15 1995.15 635
prog3 111 134 1985.15 1995.15 636
prog3 111 136 1985.15 1995.15 637
prog3 111 138 1985.15 1995.15 638
prog3 111 142 1985.15 1995.15 639
prog3 111 144 1985.15 1995.15 640
prog3 111 146 1985.15 1995.15 641
prog3 111 156 1985.15 1995.15 642
prog3 111 158 1985.15 1995.15 643
prog3 111 172 1985.15 1995.15 644
prog3 111 174 1985.15 1995.15 645
prog3 111 178 1985.15 1995.15 646
prog3 111 182 1985.15 1995.15 647
prog3 111 184 1985.15 1995.15 648
prog3 111 193 1985.15 1995.15 649
prog3 111 196 1985.15 1995.15 650
prog3 112 122 1985.15 1995.15 651
prog3 112 124 1985.15 1995.15 652
prog3 112 128 1985.15 1995.15 653
prog3 112 132 1985.15 1995.15 654
prog3 112 134 1985.15 1995.15 655
prog3 112 136 1985.15 1995.15 656
prog3 112 138 1985.15 1995.15 657
prog3 112 142 1985.15 1995.15 658
prog3 112 144 1985.15 1995.15 659
prog3 112 146 1985.15 1995.15 660
prog3 112 156 1985.15 1995.15 661
prog3 112 158 1985.15 1995.15 662
prog3 112 172 1985.15 1995.15 663
prog3 112 174 1985.15 1995.15 664
prog3 112 178 1985.15 1995.15 665
prog3 112 182 1985.15 1995.15 666
prog3 112 184 1985.15 1995.15 667
prog3 112 193 1985.15 1995.15 668
prog3 112 196 1985.15 1995.15 669
prog3 122 124 1985.15 1995.15 670
prog3 122 128 1985.15 1995.15 671
prog3 122 132 1985.15 1995.15 672
prog3 122 134 1985.15 1995.15 673
prog3 122 136 1985.15 1995.15 674
prog3 122 138 1985.15 1995.15 675
prog3 122 142 1985.15 1995.15 676
prog3 122 144 1985.15 1995.15 677
prog3 122 146 1985.15 1995.15 678
prog3 122 156 1985.15 1995.15 679
prog3 122 158 1985.15 1995.15 680
prog3 122 172 1985.15 1995.15 681
prog3 122 174 1985.15 1995.15 682
prog3 122 178 1985.15 1995.15 683
prog3 122 182 1985.15 1995.15 684
prog3 122 184 1985.15 1995.15 685
prog3 122 193 1985.15 1995.15 686
prog3 122 196 1985.15 1995.15 687
prog3 124 128 1985.15 1995.15 688
prog3 124 132 1985.15 1995.15 689
prog3 124 134 1985.15 1995.15 690
prog3 124 136 1985.15 1995.15 691
prog3 124 138 1985.15 1995.15 692
prog3 124 142 1985.15 1995.15 693
prog3 124 144 1985.15 1995.15 694
prog3 124 146 1985.15 1995.15 695
prog3 124 156 1985.15 1995.15 696
prog3 124 158 1985.15 1995.15 697
prog3 124 172 1985.15 1995.15 698
prog3 124 174 1985.15 1995.15 699
prog3 124 178 1985.15 1995.15 700
prog3 124 182 1985.15 1995.15 701
prog3 124 184 1985.15 1995.15 702
prog3 124 193 1985.15 1995.15 703
prog3 124 196 1985.15 1995.15 704
prog3 128 132 1985.15 1995.15 705
prog3 128 134 1985.15 1995.15 706
prog3 128 136 1985.15 1995.15 707
prog3 128 138 1985.15 1995.15 708
prog3 128 142 1985.15 1995.15 709
prog3 128 144 1985.15 1995.15 710
prog3 128 146 1985.15 1995.15 711
prog3 128 156 1985.15 1995.15 712
prog3 128 158 1985.15 1995.15 713
prog3 128 172 1985.15 1995.15 714
prog3 128 174 1985.15 1995.15 715
prog3 128 178 1985.15 1995.15 716
prog3 128 182 1985.15 1995.15 717
prog3 128 184 1985.15 1995.15 718
prog3 128 193 1985.15 1995.15 719
prog3 128 196 1985.15 1995.15 720
prog3 132 134 1985.15 1995.15 721
prog3 132 136 1985.15 1995.15 722
prog3 132 138 1985.15 1995.15 723
prog3 132 142 1985.15 1995.15 724
prog3 132 144 1985.15 1995.15 725
prog3 132 146 1985.15 1995.15 726
prog3 132 156 1985.15 1995.15 727
prog3 132 158 1985.15 1995.15 728
prog3 132 172 1985.15 1995.15 729
prog3 132 174 1985.15 1995.15 730
prog3 132 178 1985.15 1995.15 731
prog3 132 182 1985.15 1995.15 732
prog3 132 184 1985.15 1995.15 733
prog3 132 193 1985.15 1995.15 734
prog3 132 196 1985.15 1995.15 735
prog3 134 136 1985.15 1995.15 736
prog3 134 138 1985.15 1995.15 737
prog3 134 142 1985.15 1995.15 738
prog3 134 144 1985.15 1995.15 739
prog3 134 146 1985.15 1995.15 740
prog3 134 156 1985.15 1995.15 741
prog3 134 158 1985.15 1995.15 742
prog3 134 172 1985.15 1995.15 743
prog3 134 174 1985.15 1995.15 744
prog3 134 178 1985.15 1995.15 745
prog3 134 182 1985.15 1995.15 746
prog3 134 184 1985.15 1995.15 747
prog3 134 193 1985.15 1995.15 748
prog3 134 196 1985.15 1995.15 749
prog3 136 138 1985.15 1995.15 750
prog3 136 142 1985.15 1995.15 751
prog3 136 144 1985.15 1995.15 752
prog3 136 146 1985.15 1995.15 753
prog3 136 156 1985.15 1995.15 754
prog3 136 158 1985.15 1995.15 755
prog3 136 172 1985.15 1995.15 756
prog3 136 174 1985.15 1995.15 757
prog3 136 178 1985.15 1995.15 758
prog3 136 182 1985.15 1995.15 759
prog3 136 184 1985.15 1995.15 760
prog3 136 193 1985.15 1995.15 761
prog3 136 196 1985.15 1995.15 762
prog3 138 142 1985.15 1995.15 763
prog3 138 144 1985.15 1995.15 764
prog3 138 146 1985.15 1995.15 765
prog3 138 156 1985.15 1995.15 766
prog3 138 158 1985.15 1995.15 767
prog3 138 172 1985.15 1995.15 768
prog3 138 174 1985.15 1995.15 769
prog3 138 178 1985.15 1995.15 770
prog3 138 182 1985.15 1995.15 771
prog3 138 184 1985.15 1995.15 772
prog3 138 193 1985.15 1995.15 773
prog3 138 196 1985.15 1995.15 774
prog3 142 144 1985.15 1995.15 775
prog3 142 146 1985.15 1995.15 776
prog3 142 156 1985.15 1995.15 777
prog3 142 158 1985.15 1995.15 778
prog3 142 172 1985.15 1995.15 779
prog3 142 174 1985.15 1995.15 780
prog3 142 178 1985.15 1995.15 781
prog3 142 182 1985.15 1995.15 782
prog3 142 184 1985.15 1995.15 783
prog3 142 193 1985.15 1995.15 784
prog3 142 196 1985.15 1995.15 785
prog3 144 146 1985.15 1995.15 786
prog3 144 156 1985.15 1995.15 787
prog3 144 158 1985.15 1995.15 788
prog3 144 172 1985.15 1995.15 789
prog3 144 174 1985.15 1995.15 790
prog3 144 178 1985.15 1995.15 791
prog3 144 182 1985.15 1995.15 792
prog3 144 184 1985.15 1995.15 793
prog3 144 193 1985.15 1995.15 794
prog3 144 196 1985.15 1995.15 795
prog3 146 156 1985.15 1995.15 796
prog3 146 158 1985.15 1995.15 797
prog3 146 172 1985.15 1995.15 798
prog3 146 174 1985.15 1995.15 799
prog3 146 178 1985.15 1995.15 800
prog3 146 182 1985.15 1995.15 801
prog3 146 184 1985.15 1995.15 802
prog3 146 193 1985.15 1995.15 803
prog3 146 196 1985.15 1995.15 804
prog3 156 158 1985.15 1995.15 805
prog3 156 172 1985.15 1995.15 806
prog3 156 174 1985.15 1995.15 807
prog3 156 178 1985.15 1995.15 808
prog3 156 182 1985.15 1995.15 809
prog3 156 184 1985.15 1995.15 810
prog3 156 193 1985.15 1995.15 811
prog3 156 196 1985.15 1995.15 812
prog3 158 172 1985.15 1995.15 813
prog3 158 174 1985.15 1995.15 814
prog3 158 178 1985.15 1995.15 815
prog3 158 182 1985.15 1995.15 816
prog3 158 184 1985.15 1995.15 817
prog3 158 193 1985.15 1995.15 818
prog3 158 196 1985.15 1995.15 819
prog3 172 174 1985.15 1995.15 820
prog3 172 178 1985.15 1995.15 821
prog3 172 182 1985.15 1995.15 822
prog3 172 184 1985.15 1995.15 823
prog3 172 193 1985.15 1995.15 824
prog3 172 196 1985.15 1995.15 825
prog3 174 178 1985.15 1995.15 826
prog3 174 182 1985.15 1995.15 827
prog3 174 184 1985.15 1995.15 828
prog3 174 193 1985.15 1995.15 829
prog3 174 196 1985.15 1995.15 830
prog3 178 182 1985.15 1995.15 831
prog3 178 184 1985.15 1995.15 832
prog3 178 193 1985.15 1995.15 833
prog3 178 196 1985.15 1995.15 834
prog3 182 184 1985.15 1995.15 835
prog3 182 193 1985.15 1995.15 836
prog3 182 196 1985.15 1995.15 837
prog3 184 193 1985.15 1995.15 838
prog3 184 196 1985.15 1995.15 839
prog3 193 196 1985.15 1995.15 840
*
* Write out the data (and a few auxiliaries)
*
g period=1 in 1/210
replace period=2 in 211/420
replace period=3 in 421/630
replace period=4 in 631/840

compress
sort count1 count2 period
outfile period count1 count2 c1pop c2pop c1rgdpch c2rgdpch in 1/840 using \res\oca\data\pwtstuf,replace dictionary
program drop _all
drop _all

infile using \res\oca\data\pwtstuf
compress
sort count1 count2 period
save \res\oca\data\crap,replace
drop _all
*
* Now combine the two data sets
*
use \res\oca\data\datav3
sort count1 count2 period
merge count1 count2 period using \res\oca\data\crap
tab _merge
drop _merge
compress
sort count1 count2 period
save \res\oca\data\datav3,replace
*
* Close Down
*
!del \res\oca\data\crap*.*
!del crap*.*
program drop _all
drop _all
log close
exit,clear
