drop _all
log using p1,replace
*
* This STATA runs simple OLS regressions of bilateral real correlations on
* trade intensity
*
set more 1
set maxobs 5000
*
* Read in the data
*
use \res\oca\data\datav3

g lwt=log(wt)
g lwx=log(wx)
g lwm=log(wm)
*
* Whole Sample: Total Trade Intensity
*
hreg dy lwt
hreg di lwt
hreg de lwt
hreg du lwt
hreg ty lwt
hreg ti lwt
hreg te lwt
hreg tu lwt
hreg hy lwt
hreg hi lwt
hreg he lwt
hreg hu lwt
hreg sy lwt
hreg si lwt
hreg se lwt
hreg su lwt
*
* Whole Sample: Import Intensity
*
hreg dy lwm
hreg di lwm
hreg de lwm
hreg du lwm
hreg ty lwm
hreg ti lwm
hreg te lwm
hreg tu lwm
hreg hy lwm
hreg hi lwm
hreg he lwm
hreg hu lwm
hreg sy lwm
hreg si lwm
hreg se lwm
hreg su lwm
*
* Whole Sample: Export Intensity
*
hreg dy lwx
hreg di lwx
hreg de lwx
hreg du lwx
hreg ty lwx
hreg ti lwx
hreg te lwx
hreg tu lwx
hreg hy lwx
hreg hi lwx
hreg he lwx
hreg hu lwx
hreg sy lwx
hreg si lwx
hreg se lwx
hreg su lwx
*
* Whole Sample: Total Trade Intensity, without log transform
*
hreg dy wt
hreg di wt
hreg de wt
hreg du wt
hreg ty wt
hreg ti wt
hreg te wt
hreg tu wt
hreg hy wt
hreg hi wt
hreg he wt
hreg hu wt
hreg sy wt
hreg si wt
hreg se wt
hreg su wt
*
* Period 1 only: Total Trade Intensity
*
hreg dy lwt if period==1
hreg di lwt if period==1
hreg de lwt if period==1
hreg du lwt if period==1
hreg ty lwt if period==1
hreg ti lwt if period==1
hreg te lwt if period==1
hreg tu lwt if period==1
hreg hy lwt if period==1
hreg hi lwt if period==1
hreg he lwt if period==1
hreg hu lwt if period==1
hreg sy lwt if period==1
hreg si lwt if period==1
hreg se lwt if period==1
hreg su lwt if period==1
*
* Period 4 only: Total Trade Intensity
*
hreg dy lwt if period==4
hreg di lwt if period==4
hreg de lwt if period==4
hreg du lwt if period==4
hreg ty lwt if period==4
hreg ti lwt if period==4
hreg te lwt if period==4
hreg tu lwt if period==4
hreg hy lwt if period==4
hreg hi lwt if period==4
hreg he lwt if period==4
hreg hu lwt if period==4
hreg sy lwt if period==4
hreg si lwt if period==4
hreg se lwt if period==4
hreg su lwt if period==4
*
* Exclusion of Period 2 only: Total Trade Intensity
*
hreg dy lwt if period~=2
hreg di lwt if period~=2
hreg de lwt if period~=2
hreg du lwt if period~=2
hreg ty lwt if period~=2
hreg ti lwt if period~=2
hreg te lwt if period~=2
hreg tu lwt if period~=2
hreg hy lwt if period~=2
hreg hi lwt if period~=2
hreg he lwt if period~=2
hreg hu lwt if period~=2
hreg sy lwt if period~=2
hreg si lwt if period~=2
hreg se lwt if period~=2
hreg su lwt if period~=2
*
* Exclusion of Period 3 only: Total Trade Intensity
*
hreg dy lwt if period~=3
hreg di lwt if period~=3
hreg de lwt if period~=3
hreg du lwt if period~=3
hreg ty lwt if period~=3
hreg ti lwt if period~=3
hreg te lwt if period~=3
hreg tu lwt if period~=3
hreg hy lwt if period~=3
hreg hi lwt if period~=3
hreg he lwt if period~=3
hreg hu lwt if period~=3
hreg sy lwt if period~=3
hreg si lwt if period~=3
hreg se lwt if period~=3
hreg su lwt if period~=3
*
* Exclusion of IFS codes over 150: Total Trade Intensity
*
hreg dy lwt if count1<150&count2<150
hreg di lwt if count1<150&count2<150
hreg de lwt if count1<150&count2<150
hreg du lwt if count1<150&count2<150
hreg ty lwt if count1<150&count2<150
hreg ti lwt if count1<150&count2<150
hreg te lwt if count1<150&count2<150
hreg tu lwt if count1<150&count2<150
hreg hy lwt if count1<150&count2<150
hreg hi lwt if count1<150&count2<150
hreg he lwt if count1<150&count2<150
hreg hu lwt if count1<150&count2<150
hreg sy lwt if count1<150&count2<150
hreg si lwt if count1<150&count2<150
hreg se lwt if count1<150&count2<150
hreg su lwt if count1<150&count2<150
*
* Country-Differencing
*
g dlwt=lwt-lwt[_n-1] if period>1.5
replace dlwt=. if count1~=count1[_n-1]
replace dlwt=. if count2~=count2[_n-1]

g ddy=dy-dy[_n-1] if period>1.5
g ddi=di-di[_n-1] if period>1.5
g dde=de-de[_n-1] if period>1.5
g ddu=du-du[_n-1] if period>1.5
g dty=ty-ty[_n-1] if period>1.5
g dti=ti-ti[_n-1] if period>1.5
g dte=te-te[_n-1] if period>1.5
g dtu=tu-tu[_n-1] if period>1.5
g dhy=hy-hy[_n-1] if period>1.5
g dhi=hi-hi[_n-1] if period>1.5
g dhe=he-he[_n-1] if period>1.5
g dhu=hu-hu[_n-1] if period>1.5
g dsy=sy-sy[_n-1] if period>1.5
g dsi=si-si[_n-1] if period>1.5
g dse=se-se[_n-1] if period>1.5
g dsu=su-su[_n-1] if period>1.5
*
* Differenced Sample: Total Trade Intensity
*
hreg ddy dlwt
hreg ddi dlwt
hreg dde dlwt
hreg ddu dlwt
hreg dty dlwt
hreg dti dlwt
hreg dte dlwt
hreg dtu dlwt
hreg dhy dlwt
hreg dhi dlwt
hreg dhe dlwt
hreg dhu dlwt
hreg dsy dlwt
hreg dsi dlwt
hreg dse dlwt
hreg dsu dlwt
*
* Whole Sample: Total Trade Intensity.  OLS then Hub